needs "help.ml";;

theorems :=
[
"ABSORPTION",ABSORPTION;
"ABS_SIMP",ABS_SIMP;
"ADD",ADD;
"ADD1",ADD1;
"ADD_0",ADD_0;
"ADD_AC",ADD_AC;
"ADD_ASSOC",ADD_ASSOC;
"ADD_CLAUSES",ADD_CLAUSES;
"ADD_EQ_0",ADD_EQ_0;
"ADD_SUB",ADD_SUB;
"ADD_SUB2",ADD_SUB2;
"ADD_SUBR",ADD_SUBR;
"ADD_SUBR2",ADD_SUBR2;
"ADD_SUC",ADD_SUC;
"ADD_SYM",ADD_SYM;
"ADMISSIBLE_BASE",ADMISSIBLE_BASE;
"ADMISSIBLE_COMB",ADMISSIBLE_COMB;
"ADMISSIBLE_COND",ADMISSIBLE_COND;
"ADMISSIBLE_CONST",ADMISSIBLE_CONST;
"ADMISSIBLE_GUARDED_PATTERN",ADMISSIBLE_GUARDED_PATTERN;
"ADMISSIBLE_IMP_SUPERADMISSIBLE",ADMISSIBLE_IMP_SUPERADMISSIBLE;
"ADMISSIBLE_LAMBDA",ADMISSIBLE_LAMBDA;
"ADMISSIBLE_MAP",ADMISSIBLE_MAP;
"ADMISSIBLE_MATCH",ADMISSIBLE_MATCH;
"ADMISSIBLE_MATCH_SEQPATTERN",ADMISSIBLE_MATCH_SEQPATTERN;
"ADMISSIBLE_NEST",ADMISSIBLE_NEST;
"ADMISSIBLE_NSUM",ADMISSIBLE_NSUM;
"ADMISSIBLE_RAND",ADMISSIBLE_RAND;
"ADMISSIBLE_SEQPATTERN",ADMISSIBLE_SEQPATTERN;
"ADMISSIBLE_SUM",ADMISSIBLE_SUM;
"ADMISSIBLE_UNGUARDED_PATTERN",ADMISSIBLE_UNGUARDED_PATTERN;
"ALL",ALL;
"ALL2",ALL2;
"ALL2_ALL",ALL2_ALL;
"ALL2_AND_RIGHT",ALL2_AND_RIGHT;
"ALL2_DEF",ALL2_DEF;
"ALL2_MAP",ALL2_MAP;
"ALL2_MAP2",ALL2_MAP2;
"ALLPAIRS",ALLPAIRS;
"ALLPAIRS_EQ",ALLPAIRS_EQ;
"ALLPAIRS_MAP",ALLPAIRS_MAP;
"ALLPAIRS_MEM",ALLPAIRS_MEM;
"ALLPAIRS_SYM",ALLPAIRS_SYM;
"ALL_APPEND",ALL_APPEND;
"ALL_EL",ALL_EL;
"ALL_EQ",ALL_EQ;
"ALL_FILTER",ALL_FILTER;
"ALL_IMP",ALL_IMP;
"ALL_MAP",ALL_MAP;
"ALL_MEM",ALL_MEM;
"ALL_MP",ALL_MP;
"ALL_T",ALL_T;
"AND_ALL",AND_ALL;
"AND_ALL2",AND_ALL2;
"AND_CLAUSES",AND_CLAUSES;
"AND_DEF",AND_DEF;
"AND_FORALL_THM",AND_FORALL_THM;
"APPEND",APPEND;
"APPEND_ASSOC",APPEND_ASSOC;
"APPEND_BUTLAST_LAST",APPEND_BUTLAST_LAST;
"APPEND_EQ_NIL",APPEND_EQ_NIL;
"APPEND_LCANCEL",APPEND_LCANCEL;
"APPEND_NIL",APPEND_NIL;
"APPEND_RCANCEL",APPEND_RCANCEL;
"APPEND_SING",APPEND_SING;
"ARB",ARB;
"ARBITRARY",ARBITRARY;
"ARBITRARY_INTERSECTION_OF_COMPLEMENT",ARBITRARY_INTERSECTION_OF_COMPLEMENT;
"ARBITRARY_INTERSECTION_OF_EMPTY",ARBITRARY_INTERSECTION_OF_EMPTY;
"ARBITRARY_INTERSECTION_OF_IDEMPOT",ARBITRARY_INTERSECTION_OF_IDEMPOT;
"ARBITRARY_INTERSECTION_OF_INC",ARBITRARY_INTERSECTION_OF_INC;
"ARBITRARY_INTERSECTION_OF_INTER",ARBITRARY_INTERSECTION_OF_INTER;
"ARBITRARY_INTERSECTION_OF_INTERS",ARBITRARY_INTERSECTION_OF_INTERS;
"ARBITRARY_INTERSECTION_OF_UNION",ARBITRARY_INTERSECTION_OF_UNION;
"ARBITRARY_INTERSECTION_OF_UNION_EQ",ARBITRARY_INTERSECTION_OF_UNION_EQ;
"ARBITRARY_UNION_OF_ALT",ARBITRARY_UNION_OF_ALT;
"ARBITRARY_UNION_OF_COMPLEMENT",ARBITRARY_UNION_OF_COMPLEMENT;
"ARBITRARY_UNION_OF_EMPTY",ARBITRARY_UNION_OF_EMPTY;
"ARBITRARY_UNION_OF_IDEMPOT",ARBITRARY_UNION_OF_IDEMPOT;
"ARBITRARY_UNION_OF_INC",ARBITRARY_UNION_OF_INC;
"ARBITRARY_UNION_OF_INTER",ARBITRARY_UNION_OF_INTER;
"ARBITRARY_UNION_OF_INTER_EQ",ARBITRARY_UNION_OF_INTER_EQ;
"ARBITRARY_UNION_OF_UNION",ARBITRARY_UNION_OF_UNION;
"ARBITRARY_UNION_OF_UNIONS",ARBITRARY_UNION_OF_UNIONS;
"ARITH",ARITH;
"ARITH_ADD",ARITH_ADD;
"ARITH_EQ",ARITH_EQ;
"ARITH_EVEN",ARITH_EVEN;
"ARITH_EXP",ARITH_EXP;
"ARITH_GE",ARITH_GE;
"ARITH_GT",ARITH_GT;
"ARITH_LE",ARITH_LE;
"ARITH_LT",ARITH_LT;
"ARITH_MULT",ARITH_MULT;
"ARITH_ODD",ARITH_ODD;
"ARITH_PRE",ARITH_PRE;
"ARITH_SUB",ARITH_SUB;
"ARITH_SUC",ARITH_SUC;
"ARITH_ZERO",ARITH_ZERO;
"ASSOC",ASSOC;
"BETA_THM",BETA_THM;
"BIJ",BIJ;
"BIJECTIONS_CARD_EQ",BIJECTIONS_CARD_EQ;
"BIJECTIONS_HAS_SIZE",BIJECTIONS_HAS_SIZE;
"BIJECTIONS_HAS_SIZE_EQ",BIJECTIONS_HAS_SIZE_EQ;
"BIJECTIVE_LEFT_RIGHT_INVERSE",BIJECTIVE_LEFT_RIGHT_INVERSE;
"BIJECTIVE_ON_LEFT_RIGHT_INVERSE",BIJECTIVE_ON_LEFT_RIGHT_INVERSE;
"BINARY_INDUCT",BINARY_INDUCT;
"BIT0",BIT0;
"BIT0_0",BIT0_0;
"BIT0_DEF",BIT0_DEF;
"BIT0_THM",BIT0_THM;
"BIT1",BIT1;
"BIT1_0",BIT1_0;
"BIT1_DEF",BIT1_DEF;
"BIT1_THM",BIT1_THM;
"BOOL_CASES_AX",BOOL_CASES_AX;
"BOTTOM",BOTTOM;
"BOUNDS_DIVIDED",BOUNDS_DIVIDED;
"BOUNDS_IGNORE",BOUNDS_IGNORE;
"BOUNDS_LINEAR",BOUNDS_LINEAR;
"BOUNDS_LINEAR_0",BOUNDS_LINEAR_0;
"BOUNDS_NOTZERO",BOUNDS_NOTZERO;
"BUTLAST",BUTLAST;
"BUTLAST_APPEND",BUTLAST_APPEND;
"BUTLAST_CLAUSES",BUTLAST_CLAUSES;
"CARD",CARD;
"CARD_BOOL",CARD_BOOL;
"CARD_CART_UNIV",CARD_CART_UNIV;
"CARD_CLAUSES",CARD_CLAUSES;
"CARD_CROSS",CARD_CROSS;
"CARD_DELETE",CARD_DELETE;
"CARD_DIFF",CARD_DIFF;
"CARD_EQ_0",CARD_EQ_0;
"CARD_EQ_BIJECTION",CARD_EQ_BIJECTION;
"CARD_EQ_BIJECTIONS",CARD_EQ_BIJECTIONS;
"CARD_EQ_BIJECTIONS_SPECIAL",CARD_EQ_BIJECTIONS_SPECIAL;
"CARD_EQ_NSUM",CARD_EQ_NSUM;
"CARD_EQ_SUM",CARD_EQ_SUM;
"CARD_FINITE_IMAGE",CARD_FINITE_IMAGE;
"CARD_FUNSPACE",CARD_FUNSPACE;
"CARD_FUNSPACE_UNIV",CARD_FUNSPACE_UNIV;
"CARD_IMAGE_EQ_INJ",CARD_IMAGE_EQ_INJ;
"CARD_IMAGE_INJ",CARD_IMAGE_INJ;
"CARD_IMAGE_INJ_EQ",CARD_IMAGE_INJ_EQ;
"CARD_IMAGE_LE",CARD_IMAGE_LE;
"CARD_IMAGE_LE2",CARD_IMAGE_LE2;
"CARD_IMAGE_LT2",CARD_IMAGE_LT2;
"CARD_LE_1",CARD_LE_1;
"CARD_LE_INJ",CARD_LE_INJ;
"CARD_LE_UNIONS_CHAIN",CARD_LE_UNIONS_CHAIN;
"CARD_NUMSEG",CARD_NUMSEG;
"CARD_NUMSEG_1",CARD_NUMSEG_1;
"CARD_NUMSEG_LE",CARD_NUMSEG_LE;
"CARD_NUMSEG_LEMMA",CARD_NUMSEG_LEMMA;
"CARD_NUMSEG_LT",CARD_NUMSEG_LT;
"CARD_POWERSET",CARD_POWERSET;
"CARD_PRODUCT",CARD_PRODUCT;
"CARD_PSUBSET",CARD_PSUBSET;
"CARD_PSUBSET_EQ",CARD_PSUBSET_EQ;
"CARD_PSUBSET_IMP",CARD_PSUBSET_IMP;
"CARD_SET_OF_LIST_LE",CARD_SET_OF_LIST_LE;
"CARD_SING",CARD_SING;
"CARD_SUBSET",CARD_SUBSET;
"CARD_SUBSET_EQ",CARD_SUBSET_EQ;
"CARD_SUBSET_IMAGE",CARD_SUBSET_IMAGE;
"CARD_SUBSET_LE",CARD_SUBSET_LE;
"CARD_UNION",CARD_UNION;
"CARD_UNIONS",CARD_UNIONS;
"CARD_UNIONS_LE",CARD_UNIONS_LE;
"CARD_UNION_EQ",CARD_UNION_EQ;
"CARD_UNION_GEN",CARD_UNION_GEN;
"CARD_UNION_LE",CARD_UNION_LE;
"CARD_UNION_OVERLAP",CARD_UNION_OVERLAP;
"CARD_UNION_OVERLAP_EQ",CARD_UNION_OVERLAP_EQ;
"CARTESIAN_PRODUCT",CARTESIAN_PRODUCT;
"CARTESIAN_PRODUCT_AS_RESTRICTIONS",CARTESIAN_PRODUCT_AS_RESTRICTIONS;
"CARTESIAN_PRODUCT_EMPTY",CARTESIAN_PRODUCT_EMPTY;
"CARTESIAN_PRODUCT_EQ",CARTESIAN_PRODUCT_EQ;
"CARTESIAN_PRODUCT_EQ_EMPTY",CARTESIAN_PRODUCT_EQ_EMPTY;
"CARTESIAN_PRODUCT_EQ_MEMBERS",CARTESIAN_PRODUCT_EQ_MEMBERS;
"CARTESIAN_PRODUCT_EQ_MEMBERS_EQ",CARTESIAN_PRODUCT_EQ_MEMBERS_EQ;
"CARTESIAN_PRODUCT_SINGS",CARTESIAN_PRODUCT_SINGS;
"CARTESIAN_PRODUCT_SINGS_GEN",CARTESIAN_PRODUCT_SINGS_GEN;
"CARTESIAN_PRODUCT_UNIV",CARTESIAN_PRODUCT_UNIV;
"CART_EQ",CART_EQ;
"CART_EQ_FULL",CART_EQ_FULL;
"CASEWISE",CASEWISE;
"CASEWISE_CASES",CASEWISE_CASES;
"CASEWISE_DEF",CASEWISE_DEF;
"CASEWISE_WORKS",CASEWISE_WORKS;
"CHOICE",CHOICE;
"CHOICE_DEF",CHOICE_DEF;
"CHOICE_PAIRED_THM",CHOICE_PAIRED_THM;
"CHOICE_UNPAIR_THM",CHOICE_UNPAIR_THM;
"CHOOSE_SUBSET",CHOOSE_SUBSET;
"CHOOSE_SUBSET_BETWEEN",CHOOSE_SUBSET_BETWEEN;
"CHOOSE_SUBSET_EQ",CHOOSE_SUBSET_EQ;
"CHOOSE_SUBSET_STRONG",CHOOSE_SUBSET_STRONG;
"COMMA_DEF",COMMA_DEF;
"COMPL_COMPL",COMPL_COMPL;
"COMPONENT",COMPONENT;
"COND_ABS",COND_ABS;
"COND_CLAUSES",COND_CLAUSES;
"COND_DEF",COND_DEF;
"COND_ELIM_THM",COND_ELIM_THM;
"COND_EXPAND",COND_EXPAND;
"COND_ID",COND_ID;
"COND_RAND",COND_RAND;
"COND_RATOR",COND_RATOR;
"COND_SWAP",COND_SWAP;
"CONG",CONG;
"CONG_DIV2",CONG_DIV2;
"CONG_LMOD",CONG_LMOD;
"CONG_NSUM",CONG_NSUM;
"CONG_RMOD",CONG_RMOD;
"CONJ_ACI",CONJ_ACI;
"CONJ_ASSOC",CONJ_ASSOC;
"CONJ_SYM",CONJ_SYM;
"CONSTR",CONSTR;
"CONSTR_BOT",CONSTR_BOT;
"CONSTR_IND",CONSTR_IND;
"CONSTR_INJ",CONSTR_INJ;
"CONSTR_REC",CONSTR_REC;
"CONS_11",CONS_11;
"CONS_HD_TL",CONS_HD_TL;
"CONTRAPOS_THM",CONTRAPOS_THM;
"COPRIME_LMOD",COPRIME_LMOD;
"COPRIME_RMOD",COPRIME_RMOD;
"COUNTABLE",COUNTABLE;
"CROSS",CROSS;
"CROSS_DIFF",CROSS_DIFF;
"CROSS_EMPTY",CROSS_EMPTY;
"CROSS_EQ",CROSS_EQ;
"CROSS_EQ_EMPTY",CROSS_EQ_EMPTY;
"CROSS_INTER",CROSS_INTER;
"CROSS_INTERS",CROSS_INTERS;
"CROSS_INTERS_INTERS",CROSS_INTERS_INTERS;
"CROSS_MONO",CROSS_MONO;
"CROSS_SING",CROSS_SING;
"CROSS_UNION",CROSS_UNION;
"CROSS_UNIONS",CROSS_UNIONS;
"CROSS_UNIONS_UNIONS",CROSS_UNIONS_UNIONS;
"CROSS_UNIV",CROSS_UNIV;
"CURRY_DEF",CURRY_DEF;
"DECIMAL",DECIMAL;
"DECOMPOSITION",DECOMPOSITION;
"DELETE",DELETE;
"DELETE_COMM",DELETE_COMM;
"DELETE_DELETE",DELETE_DELETE;
"DELETE_INSERT",DELETE_INSERT;
"DELETE_INTER",DELETE_INTER;
"DELETE_NON_ELEMENT",DELETE_NON_ELEMENT;
"DELETE_SUBSET",DELETE_SUBSET;
"DEPENDENT_CHOICE",DEPENDENT_CHOICE;
"DEPENDENT_CHOICE_FIXED",DEPENDENT_CHOICE_FIXED;
"DEST_REC_INJ",DEST_REC_INJ;
"DE_MORGAN_THM",DE_MORGAN_THM;
"DIFF",DIFF;
"DIFF_DIFF",DIFF_DIFF;
"DIFF_EMPTY",DIFF_EMPTY;
"DIFF_EQ_EMPTY",DIFF_EQ_EMPTY;
"DIFF_INSERT",DIFF_INSERT;
"DIFF_INTERS",DIFF_INTERS;
"DIFF_RESTRICT",DIFF_RESTRICT;
"DIFF_UNIONS",DIFF_UNIONS;
"DIFF_UNIONS_NONEMPTY",DIFF_UNIONS_NONEMPTY;
"DIFF_UNIONS_PAIRWISE_DISJOINT",DIFF_UNIONS_PAIRWISE_DISJOINT;
"DIFF_UNIV",DIFF_UNIV;
"DIMINDEX_1",DIMINDEX_1;
"DIMINDEX_2",DIMINDEX_2;
"DIMINDEX_3",DIMINDEX_3;
"DIMINDEX_4",DIMINDEX_4;
"DIMINDEX_CLAUSES",DIMINDEX_CLAUSES;
"DIMINDEX_FINITE_DIFF",DIMINDEX_FINITE_DIFF;
"DIMINDEX_FINITE_IMAGE",DIMINDEX_FINITE_IMAGE;
"DIMINDEX_FINITE_PROD",DIMINDEX_FINITE_PROD;
"DIMINDEX_FINITE_SUM",DIMINDEX_FINITE_SUM;
"DIMINDEX_GE_1",DIMINDEX_GE_1;
"DIMINDEX_HAS_SIZE_FINITE_DIFF",DIMINDEX_HAS_SIZE_FINITE_DIFF;
"DIMINDEX_HAS_SIZE_FINITE_PROD",DIMINDEX_HAS_SIZE_FINITE_PROD;
"DIMINDEX_HAS_SIZE_FINITE_SUM",DIMINDEX_HAS_SIZE_FINITE_SUM;
"DIMINDEX_NONZERO",DIMINDEX_NONZERO;
"DIMINDEX_TYBIT0",DIMINDEX_TYBIT0;
"DIMINDEX_TYBIT1",DIMINDEX_TYBIT1;
"DIMINDEX_UNIQUE",DIMINDEX_UNIQUE;
"DIMINDEX_UNIV",DIMINDEX_UNIV;
"DISJOINT",DISJOINT;
"DISJOINT_CROSS",DISJOINT_CROSS;
"DISJOINT_DELETE_SYM",DISJOINT_DELETE_SYM;
"DISJOINT_DISJOINT_UNION",DISJOINT_DISJOINT_UNION;
"DISJOINT_EMPTY",DISJOINT_EMPTY;
"DISJOINT_EMPTY_REFL",DISJOINT_EMPTY_REFL;
"DISJOINT_INSERT",DISJOINT_INSERT;
"DISJOINT_NUMSEG",DISJOINT_NUMSEG;
"DISJOINT_PCROSS",DISJOINT_PCROSS;
"DISJOINT_SING",DISJOINT_SING;
"DISJOINT_SYM",DISJOINT_SYM;
"DISJOINT_UNION",DISJOINT_UNION;
"DISJOINT_UNION_EQ",DISJOINT_UNION_EQ;
"DISJOINT_UNION_EQ_EMPTY",DISJOINT_UNION_EQ_EMPTY;
"DISJ_ACI",DISJ_ACI;
"DISJ_ASSOC",DISJ_ASSOC;
"DISJ_SYM",DISJ_SYM;
"DIST_ADD2",DIST_ADD2;
"DIST_ADD2_REV",DIST_ADD2_REV;
"DIST_ADDBOUND",DIST_ADDBOUND;
"DIST_ELIM_THM",DIST_ELIM_THM;
"DIST_EQ_0",DIST_EQ_0;
"DIST_LADD",DIST_LADD;
"DIST_LADD_0",DIST_LADD_0;
"DIST_LE_CASES",DIST_LE_CASES;
"DIST_LMUL",DIST_LMUL;
"DIST_LZERO",DIST_LZERO;
"DIST_RADD",DIST_RADD;
"DIST_RADD_0",DIST_RADD_0;
"DIST_REFL",DIST_REFL;
"DIST_RMUL",DIST_RMUL;
"DIST_RZERO",DIST_RZERO;
"DIST_SYM",DIST_SYM;
"DIST_TRIANGLE",DIST_TRIANGLE;
"DIST_TRIANGLES_LE",DIST_TRIANGLES_LE;
"DIST_TRIANGLE_LE",DIST_TRIANGLE_LE;
"DIVIDES_ANTISYM",DIVIDES_ANTISYM;
"DIVIDES_DIVIDES_DIV",DIVIDES_DIVIDES_DIV;
"DIVIDES_DIVIDES_DIV_EQ",DIVIDES_DIVIDES_DIV_EQ;
"DIVIDES_DIVIDES_DIV_IMP",DIVIDES_DIVIDES_DIV_IMP;
"DIVIDES_DIV_DIVIDES",DIVIDES_DIV_DIVIDES;
"DIVIDES_DIV_MULT",DIVIDES_DIV_MULT;
"DIVIDES_DIV_SELF",DIVIDES_DIV_SELF;
"DIVIDES_LE",DIVIDES_LE;
"DIVIDES_LE_IMP",DIVIDES_LE_IMP;
"DIVIDES_LE_STRONG",DIVIDES_LE_STRONG;
"DIVIDES_MOD",DIVIDES_MOD;
"DIVIDES_ONE",DIVIDES_ONE;
"DIVISION",DIVISION;
"DIVISION_0",DIVISION_0;
"DIVISION_SIMP",DIVISION_SIMP;
"DIVMOD_ELIM_THM",DIVMOD_ELIM_THM;
"DIVMOD_ELIM_THM'",DIVMOD_ELIM_THM';
"DIVMOD_EXIST",DIVMOD_EXIST;
"DIVMOD_EXIST_0",DIVMOD_EXIST_0;
"DIVMOD_UNIQ",DIVMOD_UNIQ;
"DIVMOD_UNIQ_LEMMA",DIVMOD_UNIQ_LEMMA;
"DIV_0",DIV_0;
"DIV_1",DIV_1;
"DIV_ADD",DIV_ADD;
"DIV_ADD_EQ",DIV_ADD_EQ;
"DIV_ADD_EQ_EQ",DIV_ADD_EQ_EQ;
"DIV_ADD_MOD",DIV_ADD_MOD;
"DIV_BY_DIV",DIV_BY_DIV;
"DIV_DIV",DIV_DIV;
"DIV_EQ_0",DIV_EQ_0;
"DIV_EQ_EXCLUSION",DIV_EQ_EXCLUSION;
"DIV_EQ_SELF",DIV_EQ_SELF;
"DIV_EXP",DIV_EXP;
"DIV_LE",DIV_LE;
"DIV_LE_EXCLUSION",DIV_LE_EXCLUSION;
"DIV_LT",DIV_LT;
"DIV_MOD",DIV_MOD;
"DIV_MONO",DIV_MONO;
"DIV_MONO2",DIV_MONO2;
"DIV_MONO_LT",DIV_MONO_LT;
"DIV_MULT",DIV_MULT;
"DIV_MULT2",DIV_MULT2;
"DIV_MULT_ADD",DIV_MULT_ADD;
"DIV_MUL_LE",DIV_MUL_LE;
"DIV_REFL",DIV_REFL;
"DIV_UNIQ",DIV_UNIQ;
"DIV_ZERO",DIV_ZERO;
"DOUBLE_HALF",DOUBLE_HALF;
"EL",EL;
"ELEMENT_LE_SUP",ELEMENT_LE_SUP;
"EL_APPEND",EL_APPEND;
"EL_CONS",EL_CONS;
"EL_LIST_OF_SEQ",EL_LIST_OF_SEQ;
"EL_MAP",EL_MAP;
"EL_MAP2",EL_MAP2;
"EL_TL",EL_TL;
"EMPTY",EMPTY;
"EMPTY_DELETE",EMPTY_DELETE;
"EMPTY_DIFF",EMPTY_DIFF;
"EMPTY_GSPEC",EMPTY_GSPEC;
"EMPTY_NOT_UNIV",EMPTY_NOT_UNIV;
"EMPTY_NUMSEG",EMPTY_NUMSEG;
"EMPTY_SUBSET",EMPTY_SUBSET;
"EMPTY_UNION",EMPTY_UNION;
"EMPTY_UNIONS",EMPTY_UNIONS;
"EQ_ADD_LCANCEL",EQ_ADD_LCANCEL;
"EQ_ADD_LCANCEL_0",EQ_ADD_LCANCEL_0;
"EQ_ADD_RCANCEL",EQ_ADD_RCANCEL;
"EQ_ADD_RCANCEL_0",EQ_ADD_RCANCEL_0;
"EQ_CLAUSES",EQ_CLAUSES;
"EQ_DIVMOD",EQ_DIVMOD;
"EQ_EXP",EQ_EXP;
"EQ_EXT",EQ_EXT;
"EQ_IMP",EQ_IMP;
"EQ_IMP_LE",EQ_IMP_LE;
"EQ_MULT_LCANCEL",EQ_MULT_LCANCEL;
"EQ_MULT_RCANCEL",EQ_MULT_RCANCEL;
"EQ_REFL",EQ_REFL;
"EQ_SYM",EQ_SYM;
"EQ_SYM_EQ",EQ_SYM_EQ;
"EQ_TRANS",EQ_TRANS;
"EQ_UNIV",EQ_UNIV;
"ETA_AX",ETA_AX;
"EVEN",EVEN;
"EVEN_ADD",EVEN_ADD;
"EVEN_AND_ODD",EVEN_AND_ODD;
"EVEN_DOUBLE",EVEN_DOUBLE;
"EVEN_EXISTS",EVEN_EXISTS;
"EVEN_EXISTS_LEMMA",EVEN_EXISTS_LEMMA;
"EVEN_EXP",EVEN_EXP;
"EVEN_MOD",EVEN_MOD;
"EVEN_MOD_EVEN",EVEN_MOD_EVEN;
"EVEN_MULT",EVEN_MULT;
"EVEN_ODD_DECOMPOSITION",EVEN_ODD_DECOMPOSITION;
"EVEN_OR_ODD",EVEN_OR_ODD;
"EVEN_SUB",EVEN_SUB;
"EX",EX;
"EXCLUDED_MIDDLE",EXCLUDED_MIDDLE;
"EXISTS_BOOL_THM",EXISTS_BOOL_THM;
"EXISTS_CARTESIAN_PRODUCT_ELEMENT",EXISTS_CARTESIAN_PRODUCT_ELEMENT;
"EXISTS_CURRY",EXISTS_CURRY;
"EXISTS_DEF",EXISTS_DEF;
"EXISTS_EX",EXISTS_EX;
"EXISTS_FINITE_SUBSET_IMAGE",EXISTS_FINITE_SUBSET_IMAGE;
"EXISTS_FINITE_SUBSET_IMAGE_INJ",EXISTS_FINITE_SUBSET_IMAGE_INJ;
"EXISTS_INT_CASES",EXISTS_INT_CASES;
"EXISTS_IN_CLAUSES",EXISTS_IN_CLAUSES;
"EXISTS_IN_CROSS",EXISTS_IN_CROSS;
"EXISTS_IN_GSPEC",EXISTS_IN_GSPEC;
"EXISTS_IN_IMAGE",EXISTS_IN_IMAGE;
"EXISTS_IN_INSERT",EXISTS_IN_INSERT;
"EXISTS_IN_PCROSS",EXISTS_IN_PCROSS;
"EXISTS_IN_UNION",EXISTS_IN_UNION;
"EXISTS_IN_UNIONS",EXISTS_IN_UNIONS;
"EXISTS_LT_MOD_THM",EXISTS_LT_MOD_THM;
"EXISTS_MOD_THM",EXISTS_MOD_THM;
"EXISTS_NOT_THM",EXISTS_NOT_THM;
"EXISTS_ONE_REP",EXISTS_ONE_REP;
"EXISTS_ONE_THM",EXISTS_ONE_THM;
"EXISTS_OPTION_THM",EXISTS_OPTION_THM;
"EXISTS_OR_THM",EXISTS_OR_THM;
"EXISTS_PAIRED_THM",EXISTS_PAIRED_THM;
"EXISTS_PAIR_FUN_THM",EXISTS_PAIR_FUN_THM;
"EXISTS_PAIR_THM",EXISTS_PAIR_THM;
"EXISTS_PASTECART",EXISTS_PASTECART;
"EXISTS_REFL",EXISTS_REFL;
"EXISTS_SIMP",EXISTS_SIMP;
"EXISTS_SMALL_SUBSET_IMAGE",EXISTS_SMALL_SUBSET_IMAGE;
"EXISTS_SMALL_SUBSET_IMAGE_INJ",EXISTS_SMALL_SUBSET_IMAGE_INJ;
"EXISTS_SUBSET_IMAGE",EXISTS_SUBSET_IMAGE;
"EXISTS_SUBSET_IMAGE_INJ",EXISTS_SUBSET_IMAGE_INJ;
"EXISTS_SUBSET_INSERT",EXISTS_SUBSET_INSERT;
"EXISTS_SUBSET_UNION",EXISTS_SUBSET_UNION;
"EXISTS_SWAP_FUN_THM",EXISTS_SWAP_FUN_THM;
"EXISTS_THM",EXISTS_THM;
"EXISTS_TRIPLED_THM",EXISTS_TRIPLED_THM;
"EXISTS_UNCURRY",EXISTS_UNCURRY;
"EXISTS_UNIQUE",EXISTS_UNIQUE;
"EXISTS_UNIQUE_ALT",EXISTS_UNIQUE_ALT;
"EXISTS_UNIQUE_DEF",EXISTS_UNIQUE_DEF;
"EXISTS_UNIQUE_REFL",EXISTS_UNIQUE_REFL;
"EXISTS_UNIQUE_THM",EXISTS_UNIQUE_THM;
"EXISTS_UNPAIR_FUN_THM",EXISTS_UNPAIR_FUN_THM;
"EXISTS_UNPAIR_THM",EXISTS_UNPAIR_THM;
"EXP",EXP;
"EXP_1",EXP_1;
"EXP_2",EXP_2;
"EXP_2_NE_0",EXP_2_NE_0;
"EXP_ADD",EXP_ADD;
"EXP_EQ_0",EXP_EQ_0;
"EXP_EQ_1",EXP_EQ_1;
"EXP_EXP",EXP_EXP;
"EXP_LT_0",EXP_LT_0;
"EXP_MONO_EQ",EXP_MONO_EQ;
"EXP_MONO_LE",EXP_MONO_LE;
"EXP_MONO_LE_IMP",EXP_MONO_LE_IMP;
"EXP_MONO_LT",EXP_MONO_LT;
"EXP_MONO_LT_IMP",EXP_MONO_LT_IMP;
"EXP_MULT",EXP_MULT;
"EXP_ONE",EXP_ONE;
"EXP_ZERO",EXP_ZERO;
"EXTENSION",EXTENSION;
"EXTENSIONAL",EXTENSIONAL;
"EXTENSIONAL_EMPTY",EXTENSIONAL_EMPTY;
"EXTENSIONAL_EQ",EXTENSIONAL_EQ;
"EXTENSIONAL_UNIV",EXTENSIONAL_UNIV;
"EX_IMP",EX_IMP;
"EX_MAP",EX_MAP;
"EX_MEM",EX_MEM;
"FACT",FACT;
"FACT_LE",FACT_LE;
"FACT_LT",FACT_LT;
"FACT_MONO",FACT_MONO;
"FACT_NZ",FACT_NZ;
"FCONS",FCONS;
"FCONS_UNDO",FCONS_UNDO;
"FILTER",FILTER;
"FILTER_APPEND",FILTER_APPEND;
"FILTER_MAP",FILTER_MAP;
"FINITE_1",FINITE_1;
"FINITE_BOOL",FINITE_BOOL;
"FINITE_CARD_LE_IMAGE",FINITE_CARD_LE_IMAGE;
"FINITE_CARD_LE_SUBSET",FINITE_CARD_LE_SUBSET;
"FINITE_CARD_LE_UNION",FINITE_CARD_LE_UNION;
"FINITE_CARD_LE_UNIONS",FINITE_CARD_LE_UNIONS;
"FINITE_CART",FINITE_CART;
"FINITE_CART_UNIV",FINITE_CART_UNIV;
"FINITE_CASES",FINITE_CASES;
"FINITE_CLAUSES",FINITE_CLAUSES;
"FINITE_CROSS",FINITE_CROSS;
"FINITE_CROSS_EQ",FINITE_CROSS_EQ;
"FINITE_CROSS_UNIV",FINITE_CROSS_UNIV;
"FINITE_DELETE",FINITE_DELETE;
"FINITE_DELETE_IMP",FINITE_DELETE_IMP;
"FINITE_DIFF",FINITE_DIFF;
"FINITE_DIFF_IMAGE",FINITE_DIFF_IMAGE;
"FINITE_EMPTY",FINITE_EMPTY;
"FINITE_FINITE_IMAGE",FINITE_FINITE_IMAGE;
"FINITE_FINITE_PREIMAGE",FINITE_FINITE_PREIMAGE;
"FINITE_FINITE_PREIMAGE_GENERAL",FINITE_FINITE_PREIMAGE_GENERAL;
"FINITE_FINITE_UNIONS",FINITE_FINITE_UNIONS;
"FINITE_FUNSPACE",FINITE_FUNSPACE;
"FINITE_FUNSPACE_UNIV",FINITE_FUNSPACE_UNIV;
"FINITE_HAS_SIZE",FINITE_HAS_SIZE;
"FINITE_IMAGE",FINITE_IMAGE;
"FINITE_IMAGE_EQ",FINITE_IMAGE_EQ;
"FINITE_IMAGE_EQ_INJ",FINITE_IMAGE_EQ_INJ;
"FINITE_IMAGE_EXPAND",FINITE_IMAGE_EXPAND;
"FINITE_IMAGE_GEN",FINITE_IMAGE_GEN;
"FINITE_IMAGE_IMAGE",FINITE_IMAGE_IMAGE;
"FINITE_IMAGE_INFINITE",FINITE_IMAGE_INFINITE;
"FINITE_IMAGE_INJ",FINITE_IMAGE_INJ;
"FINITE_IMAGE_INJ_EQ",FINITE_IMAGE_INJ_EQ;
"FINITE_IMAGE_INJ_GENERAL",FINITE_IMAGE_INJ_GENERAL;
"FINITE_INDEX_INJ",FINITE_INDEX_INJ;
"FINITE_INDEX_INRANGE",FINITE_INDEX_INRANGE;
"FINITE_INDEX_INRANGE_2",FINITE_INDEX_INRANGE_2;
"FINITE_INDEX_NUMBERS",FINITE_INDEX_NUMBERS;
"FINITE_INDEX_NUMSEG",FINITE_INDEX_NUMSEG;
"FINITE_INDEX_WORKS",FINITE_INDEX_WORKS;
"FINITE_INDUCT",FINITE_INDUCT;
"FINITE_INDUCT_DELETE",FINITE_INDUCT_DELETE;
"FINITE_INDUCT_STRONG",FINITE_INDUCT_STRONG;
"FINITE_INSERT",FINITE_INSERT;
"FINITE_INTER",FINITE_INTER;
"FINITE_INTERSECTION_OF_COMPLEMENT",FINITE_INTERSECTION_OF_COMPLEMENT;
"FINITE_INTERSECTION_OF_EMPTY",FINITE_INTERSECTION_OF_EMPTY;
"FINITE_INTERSECTION_OF_IDEMPOT",FINITE_INTERSECTION_OF_IDEMPOT;
"FINITE_INTERSECTION_OF_INC",FINITE_INTERSECTION_OF_INC;
"FINITE_INTERSECTION_OF_INTER",FINITE_INTERSECTION_OF_INTER;
"FINITE_INTERSECTION_OF_INTERS",FINITE_INTERSECTION_OF_INTERS;
"FINITE_INTERSECTION_OF_UNION",FINITE_INTERSECTION_OF_UNION;
"FINITE_INTERSECTION_OF_UNION_EQ",FINITE_INTERSECTION_OF_UNION_EQ;
"FINITE_INT_SEG",FINITE_INT_SEG;
"FINITE_NUMSEG",FINITE_NUMSEG;
"FINITE_NUMSEG_LE",FINITE_NUMSEG_LE;
"FINITE_NUMSEG_LT",FINITE_NUMSEG_LT;
"FINITE_PCROSS",FINITE_PCROSS;
"FINITE_PCROSS_EQ",FINITE_PCROSS_EQ;
"FINITE_POWERSET",FINITE_POWERSET;
"FINITE_POWERSET_EQ",FINITE_POWERSET_EQ;
"FINITE_PRODUCT",FINITE_PRODUCT;
"FINITE_PRODUCT_DEPENDENT",FINITE_PRODUCT_DEPENDENT;
"FINITE_PROD_IMAGE",FINITE_PROD_IMAGE;
"FINITE_REAL_INTERVAL",FINITE_REAL_INTERVAL;
"FINITE_RECURSION",FINITE_RECURSION;
"FINITE_RECURSION_DELETE",FINITE_RECURSION_DELETE;
"FINITE_RESTRICT",FINITE_RESTRICT;
"FINITE_RESTRICTED_FUNSPACE",FINITE_RESTRICTED_FUNSPACE;
"FINITE_RESTRICTED_POWERSET",FINITE_RESTRICTED_POWERSET;
"FINITE_RESTRICTED_SUBSETS",FINITE_RESTRICTED_SUBSETS;
"FINITE_RULES",FINITE_RULES;
"FINITE_SET_OF_LIST",FINITE_SET_OF_LIST;
"FINITE_SING",FINITE_SING;
"FINITE_SUBSET",FINITE_SUBSET;
"FINITE_SUBSET_IMAGE",FINITE_SUBSET_IMAGE;
"FINITE_SUBSET_IMAGE_IMP",FINITE_SUBSET_IMAGE_IMP;
"FINITE_SUBSET_NUMSEG",FINITE_SUBSET_NUMSEG;
"FINITE_SUBSET_UNIONS",FINITE_SUBSET_UNIONS;
"FINITE_SUBSET_UNIONS_CHAIN",FINITE_SUBSET_UNIONS_CHAIN;
"FINITE_SUM_IMAGE",FINITE_SUM_IMAGE;
"FINITE_SUPPORT",FINITE_SUPPORT;
"FINITE_SUPPORT_DELTA",FINITE_SUPPORT_DELTA;
"FINITE_TRANSITIVITY_CHAIN",FINITE_TRANSITIVITY_CHAIN;
"FINITE_TYBIT0",FINITE_TYBIT0;
"FINITE_TYBIT1",FINITE_TYBIT1;
"FINITE_UNION",FINITE_UNION;
"FINITE_UNIONS",FINITE_UNIONS;
"FINITE_UNION_IMP",FINITE_UNION_IMP;
"FINITE_UNION_OF_COMPLEMENT",FINITE_UNION_OF_COMPLEMENT;
"FINITE_UNION_OF_EMPTY",FINITE_UNION_OF_EMPTY;
"FINITE_UNION_OF_IDEMPOT",FINITE_UNION_OF_IDEMPOT;
"FINITE_UNION_OF_INC",FINITE_UNION_OF_INC;
"FINITE_UNION_OF_INTER",FINITE_UNION_OF_INTER;
"FINITE_UNION_OF_INTER_EQ",FINITE_UNION_OF_INTER_EQ;
"FINITE_UNION_OF_UNION",FINITE_UNION_OF_UNION;
"FINITE_UNION_OF_UNIONS",FINITE_UNION_OF_UNIONS;
"FINITE_UNIV_PAIR",FINITE_UNIV_PAIR;
"FINREC",FINREC;
"FINREC_1_LEMMA",FINREC_1_LEMMA;
"FINREC_EXISTS_LEMMA",FINREC_EXISTS_LEMMA;
"FINREC_FUN",FINREC_FUN;
"FINREC_FUN_LEMMA",FINREC_FUN_LEMMA;
"FINREC_SUC_LEMMA",FINREC_SUC_LEMMA;
"FINREC_UNIQUE_LEMMA",FINREC_UNIQUE_LEMMA;
"FNIL",FNIL;
"FORALL_ALL",FORALL_ALL;
"FORALL_AND_THM",FORALL_AND_THM;
"FORALL_BOOL_THM",FORALL_BOOL_THM;
"FORALL_CARTESIAN_PRODUCT_ELEMENTS",FORALL_CARTESIAN_PRODUCT_ELEMENTS;
"FORALL_CARTESIAN_PRODUCT_ELEMENTS_EQ",FORALL_CARTESIAN_PRODUCT_ELEMENTS_EQ;
"FORALL_CURRY",FORALL_CURRY;
"FORALL_DEF",FORALL_DEF;
"FORALL_FINITE_INDEX",FORALL_FINITE_INDEX;
"FORALL_FINITE_SUBSET_IMAGE",FORALL_FINITE_SUBSET_IMAGE;
"FORALL_FINITE_SUBSET_IMAGE_INJ",FORALL_FINITE_SUBSET_IMAGE_INJ;
"FORALL_INTERSECTION_OF",FORALL_INTERSECTION_OF;
"FORALL_INT_CASES",FORALL_INT_CASES;
"FORALL_IN_CLAUSES",FORALL_IN_CLAUSES;
"FORALL_IN_CROSS",FORALL_IN_CROSS;
"FORALL_IN_GSPEC",FORALL_IN_GSPEC;
"FORALL_IN_IMAGE",FORALL_IN_IMAGE;
"FORALL_IN_IMAGE_2",FORALL_IN_IMAGE_2;
"FORALL_IN_INSERT",FORALL_IN_INSERT;
"FORALL_IN_PCROSS",FORALL_IN_PCROSS;
"FORALL_IN_UNION",FORALL_IN_UNION;
"FORALL_IN_UNIONS",FORALL_IN_UNIONS;
"FORALL_LT_MOD_THM",FORALL_LT_MOD_THM;
"FORALL_MOD_THM",FORALL_MOD_THM;
"FORALL_NOT_THM",FORALL_NOT_THM;
"FORALL_ONE_THM",FORALL_ONE_THM;
"FORALL_OPTION_THM",FORALL_OPTION_THM;
"FORALL_PAIRED_THM",FORALL_PAIRED_THM;
"FORALL_PAIR_FUN_THM",FORALL_PAIR_FUN_THM;
"FORALL_PAIR_THM",FORALL_PAIR_THM;
"FORALL_PASTECART",FORALL_PASTECART;
"FORALL_SIMP",FORALL_SIMP;
"FORALL_SMALL_SUBSET_IMAGE",FORALL_SMALL_SUBSET_IMAGE;
"FORALL_SMALL_SUBSET_IMAGE_INJ",FORALL_SMALL_SUBSET_IMAGE_INJ;
"FORALL_SUBSET_IMAGE",FORALL_SUBSET_IMAGE;
"FORALL_SUBSET_IMAGE_INJ",FORALL_SUBSET_IMAGE_INJ;
"FORALL_SUBSET_INSERT",FORALL_SUBSET_INSERT;
"FORALL_SUBSET_UNION",FORALL_SUBSET_UNION;
"FORALL_TRIPLED_THM",FORALL_TRIPLED_THM;
"FORALL_UNCURRY",FORALL_UNCURRY;
"FORALL_UNION_OF",FORALL_UNION_OF;
"FORALL_UNPAIR_FUN_THM",FORALL_UNPAIR_FUN_THM;
"FORALL_UNPAIR_THM",FORALL_UNPAIR_THM;
"FORALL_UNWIND_THM1",FORALL_UNWIND_THM1;
"FORALL_UNWIND_THM2",FORALL_UNWIND_THM2;
"FST",FST;
"FSTCART_COMPONENT",FSTCART_COMPONENT;
"FSTCART_PASTECART",FSTCART_PASTECART;
"FST_DEF",FST_DEF;
"FUNCTION_FACTORS_LEFT",FUNCTION_FACTORS_LEFT;
"FUNCTION_FACTORS_LEFT_GEN",FUNCTION_FACTORS_LEFT_GEN;
"FUNCTION_FACTORS_RIGHT",FUNCTION_FACTORS_RIGHT;
"FUNCTION_FACTORS_RIGHT_GEN",FUNCTION_FACTORS_RIGHT_GEN;
"FUN_EQ_THM",FUN_EQ_THM;
"FUN_IN_IMAGE",FUN_IN_IMAGE;
"F_DEF",F_DEF;
"GABS_DEF",GABS_DEF;
"GCD",GCD;
"GE",GE;
"GEQ_DEF",GEQ_DEF;
"GE_C",GE_C;
"GSPEC",GSPEC;
"GT",GT;
"HALF_DOUBLE",HALF_DOUBLE;
"HAS_INF",HAS_INF;
"HAS_INF_APPROACH",HAS_INF_APPROACH;
"HAS_INF_INF",HAS_INF_INF;
"HAS_INF_LBOUND",HAS_INF_LBOUND;
"HAS_INF_LE",HAS_INF_LE;
"HAS_SIZE",HAS_SIZE;
"HAS_SIZE_0",HAS_SIZE_0;
"HAS_SIZE_1",HAS_SIZE_1;
"HAS_SIZE_2",HAS_SIZE_2;
"HAS_SIZE_3",HAS_SIZE_3;
"HAS_SIZE_4",HAS_SIZE_4;
"HAS_SIZE_BOOL",HAS_SIZE_BOOL;
"HAS_SIZE_CARD",HAS_SIZE_CARD;
"HAS_SIZE_CART_UNIV",HAS_SIZE_CART_UNIV;
"HAS_SIZE_CLAUSES",HAS_SIZE_CLAUSES;
"HAS_SIZE_CROSS",HAS_SIZE_CROSS;
"HAS_SIZE_DIFF",HAS_SIZE_DIFF;
"HAS_SIZE_FINITE_IMAGE",HAS_SIZE_FINITE_IMAGE;
"HAS_SIZE_FUNSPACE",HAS_SIZE_FUNSPACE;
"HAS_SIZE_FUNSPACE_UNIV",HAS_SIZE_FUNSPACE_UNIV;
"HAS_SIZE_IMAGE_INJ",HAS_SIZE_IMAGE_INJ;
"HAS_SIZE_IMAGE_INJ_EQ",HAS_SIZE_IMAGE_INJ_EQ;
"HAS_SIZE_IMAGE_INJ_RESTRICT",HAS_SIZE_IMAGE_INJ_RESTRICT;
"HAS_SIZE_INDEX",HAS_SIZE_INDEX;
"HAS_SIZE_NUMSEG",HAS_SIZE_NUMSEG;
"HAS_SIZE_NUMSEG_1",HAS_SIZE_NUMSEG_1;
"HAS_SIZE_NUMSEG_LE",HAS_SIZE_NUMSEG_LE;
"HAS_SIZE_NUMSEG_LT",HAS_SIZE_NUMSEG_LT;
"HAS_SIZE_PCROSS",HAS_SIZE_PCROSS;
"HAS_SIZE_POWERSET",HAS_SIZE_POWERSET;
"HAS_SIZE_PRODUCT",HAS_SIZE_PRODUCT;
"HAS_SIZE_PRODUCT_DEPENDENT",HAS_SIZE_PRODUCT_DEPENDENT;
"HAS_SIZE_SET_OF_LIST",HAS_SIZE_SET_OF_LIST;
"HAS_SIZE_SUC",HAS_SIZE_SUC;
"HAS_SIZE_TYBIT0",HAS_SIZE_TYBIT0;
"HAS_SIZE_TYBIT1",HAS_SIZE_TYBIT1;
"HAS_SIZE_UNION",HAS_SIZE_UNION;
"HAS_SIZE_UNIONS",HAS_SIZE_UNIONS;
"HAS_SUP",HAS_SUP;
"HAS_SUP_APPROACH",HAS_SUP_APPROACH;
"HAS_SUP_LE",HAS_SUP_LE;
"HAS_SUP_SUP",HAS_SUP_SUP;
"HAS_SUP_UBOUND",HAS_SUP_UBOUND;
"HD",HD;
"HD_APPEND",HD_APPEND;
"HD_REVERSE",HD_REVERSE;
"HREAL_ADD_AC",HREAL_ADD_AC;
"HREAL_ADD_ASSOC",HREAL_ADD_ASSOC;
"HREAL_ADD_LCANCEL",HREAL_ADD_LCANCEL;
"HREAL_ADD_LDISTRIB",HREAL_ADD_LDISTRIB;
"HREAL_ADD_LID",HREAL_ADD_LID;
"HREAL_ADD_RDISTRIB",HREAL_ADD_RDISTRIB;
"HREAL_ADD_RID",HREAL_ADD_RID;
"HREAL_ADD_SYM",HREAL_ADD_SYM;
"HREAL_ARCH",HREAL_ARCH;
"HREAL_COMPLETE",HREAL_COMPLETE;
"HREAL_EQ_ADD_LCANCEL",HREAL_EQ_ADD_LCANCEL;
"HREAL_EQ_ADD_RCANCEL",HREAL_EQ_ADD_RCANCEL;
"HREAL_INV_0",HREAL_INV_0;
"HREAL_LE_ADD",HREAL_LE_ADD;
"HREAL_LE_ADD2",HREAL_LE_ADD2;
"HREAL_LE_ADD_LCANCEL",HREAL_LE_ADD_LCANCEL;
"HREAL_LE_ADD_RCANCEL",HREAL_LE_ADD_RCANCEL;
"HREAL_LE_ANTISYM",HREAL_LE_ANTISYM;
"HREAL_LE_EXISTS",HREAL_LE_EXISTS;
"HREAL_LE_EXISTS_DEF",HREAL_LE_EXISTS_DEF;
"HREAL_LE_MUL_RCANCEL_IMP",HREAL_LE_MUL_RCANCEL_IMP;
"HREAL_LE_REFL",HREAL_LE_REFL;
"HREAL_LE_TOTAL",HREAL_LE_TOTAL;
"HREAL_LE_TRANS",HREAL_LE_TRANS;
"HREAL_MUL_ASSOC",HREAL_MUL_ASSOC;
"HREAL_MUL_LID",HREAL_MUL_LID;
"HREAL_MUL_LINV",HREAL_MUL_LINV;
"HREAL_MUL_LZERO",HREAL_MUL_LZERO;
"HREAL_MUL_RZERO",HREAL_MUL_RZERO;
"HREAL_MUL_SYM",HREAL_MUL_SYM;
"HREAL_OF_NUM_ADD",HREAL_OF_NUM_ADD;
"HREAL_OF_NUM_EQ",HREAL_OF_NUM_EQ;
"HREAL_OF_NUM_LE",HREAL_OF_NUM_LE;
"HREAL_OF_NUM_MUL",HREAL_OF_NUM_MUL;
"Hashek.hashek_def",Hashek.hashek_def;
"Hashek.hashek_eq",Hashek.hashek_eq;
"Hashek.hashek_prop",Hashek.hashek_prop;
"Hashek.hashek_thm",Hashek.hashek_thm;
"IMAGE",IMAGE;
"IMAGE_CLAUSES",IMAGE_CLAUSES;
"IMAGE_CONST",IMAGE_CONST;
"IMAGE_DELETE_INJ",IMAGE_DELETE_INJ;
"IMAGE_DELETE_INJ_ALT",IMAGE_DELETE_INJ_ALT;
"IMAGE_DIFF_INJ",IMAGE_DIFF_INJ;
"IMAGE_DIFF_INJ_ALT",IMAGE_DIFF_INJ_ALT;
"IMAGE_EQ",IMAGE_EQ;
"IMAGE_EQ_EMPTY",IMAGE_EQ_EMPTY;
"IMAGE_FSTCART_PCROSS",IMAGE_FSTCART_PCROSS;
"IMAGE_FST_CROSS",IMAGE_FST_CROSS;
"IMAGE_I",IMAGE_I;
"IMAGE_ID",IMAGE_ID;
"IMAGE_IMP_INJECTIVE",IMAGE_IMP_INJECTIVE;
"IMAGE_IMP_INJECTIVE_GEN",IMAGE_IMP_INJECTIVE_GEN;
"IMAGE_INJECTIVE_IMAGE_OF_SUBSET",IMAGE_INJECTIVE_IMAGE_OF_SUBSET;
"IMAGE_INTERS",IMAGE_INTERS;
"IMAGE_INTERS_SATURATED",IMAGE_INTERS_SATURATED;
"IMAGE_INTERS_SATURATED_GEN",IMAGE_INTERS_SATURATED_GEN;
"IMAGE_INTERS_SUBSET",IMAGE_INTERS_SUBSET;
"IMAGE_INTER_INJ",IMAGE_INTER_INJ;
"IMAGE_INTER_SATURATED",IMAGE_INTER_SATURATED;
"IMAGE_INTER_SATURATED_GEN",IMAGE_INTER_SATURATED_GEN;
"IMAGE_INTER_SUBSET",IMAGE_INTER_SUBSET;
"IMAGE_PAIRED_CROSS",IMAGE_PAIRED_CROSS;
"IMAGE_PRODUCT_MAP",IMAGE_PRODUCT_MAP;
"IMAGE_PROJECTION_CARTESIAN_PRODUCT",IMAGE_PROJECTION_CARTESIAN_PRODUCT;
"IMAGE_RESTRICTION",IMAGE_RESTRICTION;
"IMAGE_SNDCART_PCROSS",IMAGE_SNDCART_PCROSS;
"IMAGE_SND_CROSS",IMAGE_SND_CROSS;
"IMAGE_SUBSET",IMAGE_SUBSET;
"IMAGE_UNION",IMAGE_UNION;
"IMAGE_UNIONS",IMAGE_UNIONS;
"IMAGE_o",IMAGE_o;
"IMP_CLAUSES",IMP_CLAUSES;
"IMP_CONJ",IMP_CONJ;
"IMP_CONJ_ALT",IMP_CONJ_ALT;
"IMP_DEF",IMP_DEF;
"IMP_IMP",IMP_IMP;
"IN",IN;
"IND_SUC_0",IND_SUC_0;
"IND_SUC_0_EXISTS",IND_SUC_0_EXISTS;
"IND_SUC_INJ",IND_SUC_INJ;
"IND_SUC_SPEC",IND_SUC_SPEC;
"INF",INF;
"INFINITE",INFINITE;
"INFINITE_CROSS_EQ",INFINITE_CROSS_EQ;
"INFINITE_CROSS_UNIV",INFINITE_CROSS_UNIV;
"INFINITE_DIFF_FINITE",INFINITE_DIFF_FINITE;
"INFINITE_ENUMERATE",INFINITE_ENUMERATE;
"INFINITE_ENUMERATE_EQ",INFINITE_ENUMERATE_EQ;
"INFINITE_ENUMERATE_SUBSET",INFINITE_ENUMERATE_SUBSET;
"INFINITE_IMAGE",INFINITE_IMAGE;
"INFINITE_IMAGE_INJ",INFINITE_IMAGE_INJ;
"INFINITE_NONEMPTY",INFINITE_NONEMPTY;
"INFINITE_SUPERSET",INFINITE_SUPERSET;
"INFINITE_UNIV_PAIR",INFINITE_UNIV_PAIR;
"INFINITY_AX",INFINITY_AX;
"INF_APPROACH",INF_APPROACH;
"INF_EQ",INF_EQ;
"INF_EXISTS",INF_EXISTS;
"INF_FINITE",INF_FINITE;
"INF_FINITE_LEMMA",INF_FINITE_LEMMA;
"INF_INSERT_FINITE",INF_INSERT_FINITE;
"INF_INSERT_INSERT",INF_INSERT_INSERT;
"INF_LE_ELEMENT",INF_LE_ELEMENT;
"INF_SING",INF_SING;
"INF_UNION",INF_UNION;
"INF_UNIQUE",INF_UNIQUE;
"INF_UNIQUE_FINITE",INF_UNIQUE_FINITE;
"INJ",INJ;
"INJA",INJA;
"INJA_INJ",INJA_INJ;
"INJECTIVE_ALT",INJECTIVE_ALT;
"INJECTIVE_IMAGE",INJECTIVE_IMAGE;
"INJECTIVE_LEFT_INVERSE",INJECTIVE_LEFT_INVERSE;
"INJECTIVE_MAP",INJECTIVE_MAP;
"INJECTIVE_ON_ALT",INJECTIVE_ON_ALT;
"INJECTIVE_ON_IMAGE",INJECTIVE_ON_IMAGE;
"INJECTIVE_ON_LEFT_INVERSE",INJECTIVE_ON_LEFT_INVERSE;
"INJECTIVE_ON_PREIMAGE",INJECTIVE_ON_PREIMAGE;
"INJECTIVE_PREIMAGE",INJECTIVE_PREIMAGE;
"INJF",INJF;
"INJF_INJ",INJF_INJ;
"INJN",INJN;
"INJN_INJ",INJN_INJ;
"INJP",INJP;
"INJP_INJ",INJP_INJ;
"INJ_INVERSE2",INJ_INVERSE2;
"INSERT",INSERT;
"INSERT_AC",INSERT_AC;
"INSERT_COMM",INSERT_COMM;
"INSERT_DEF",INSERT_DEF;
"INSERT_DELETE",INSERT_DELETE;
"INSERT_DIFF",INSERT_DIFF;
"INSERT_INSERT",INSERT_INSERT;
"INSERT_INTER",INSERT_INTER;
"INSERT_RESTRICT",INSERT_RESTRICT;
"INSERT_SUBSET",INSERT_SUBSET;
"INSERT_UNION",INSERT_UNION;
"INSERT_UNION_EQ",INSERT_UNION_EQ;
"INSERT_UNIV",INSERT_UNIV;
"INTEGER_REAL_OF_INT",INTEGER_REAL_OF_INT;
"INTER",INTER;
"INTERS",INTERS;
"INTERSECTION_OF",INTERSECTION_OF;
"INTERSECTION_OF_EMPTY",INTERSECTION_OF_EMPTY;
"INTERSECTION_OF_INC",INTERSECTION_OF_INC;
"INTERSECTION_OF_MONO",INTERSECTION_OF_MONO;
"INTERS_0",INTERS_0;
"INTERS_1",INTERS_1;
"INTERS_2",INTERS_2;
"INTERS_ANTIMONO",INTERS_ANTIMONO;
"INTERS_ANTIMONO_GEN",INTERS_ANTIMONO_GEN;
"INTERS_EQ_UNIV",INTERS_EQ_UNIV;
"INTERS_GSPEC",INTERS_GSPEC;
"INTERS_IMAGE",INTERS_IMAGE;
"INTERS_INSERT",INTERS_INSERT;
"INTERS_IN_CHAIN",INTERS_IN_CHAIN;
"INTERS_OVER_UNIONS",INTERS_OVER_UNIONS;
"INTERS_SUBSET",INTERS_SUBSET;
"INTERS_SUBSET_STRONG",INTERS_SUBSET_STRONG;
"INTERS_UNION",INTERS_UNION;
"INTERS_UNIONS",INTERS_UNIONS;
"INTER_ACI",INTER_ACI;
"INTER_ASSOC",INTER_ASSOC;
"INTER_CARTESIAN_PRODUCT",INTER_CARTESIAN_PRODUCT;
"INTER_COMM",INTER_COMM;
"INTER_CROSS",INTER_CROSS;
"INTER_DISJOINT_UNION",INTER_DISJOINT_UNION;
"INTER_EMPTY",INTER_EMPTY;
"INTER_IDEMPOT",INTER_IDEMPOT;
"INTER_INTERS",INTER_INTERS;
"INTER_NUMSEG",INTER_NUMSEG;
"INTER_OVER_UNION",INTER_OVER_UNION;
"INTER_PCROSS",INTER_PCROSS;
"INTER_RESTRICT",INTER_RESTRICT;
"INTER_SUBSET",INTER_SUBSET;
"INTER_UNIONS",INTER_UNIONS;
"INTER_UNIONS_PAIRWISE_DISJOINT",INTER_UNIONS_PAIRWISE_DISJOINT;
"INTER_UNIV",INTER_UNIV;
"INT_2_DIVIDES_ADD",INT_2_DIVIDES_ADD;
"INT_2_DIVIDES_MUL",INT_2_DIVIDES_MUL;
"INT_2_DIVIDES_POW",INT_2_DIVIDES_POW;
"INT_2_DIVIDES_SUB",INT_2_DIVIDES_SUB;
"INT_ABS",INT_ABS;
"INT_ABS_0",INT_ABS_0;
"INT_ABS_1",INT_ABS_1;
"INT_ABS_ABS",INT_ABS_ABS;
"INT_ABS_BETWEEN",INT_ABS_BETWEEN;
"INT_ABS_BETWEEN1",INT_ABS_BETWEEN1;
"INT_ABS_BETWEEN2",INT_ABS_BETWEEN2;
"INT_ABS_BOUND",INT_ABS_BOUND;
"INT_ABS_BOUNDS",INT_ABS_BOUNDS;
"INT_ABS_CASES",INT_ABS_CASES;
"INT_ABS_CIRCLE",INT_ABS_CIRCLE;
"INT_ABS_LE",INT_ABS_LE;
"INT_ABS_MUL",INT_ABS_MUL;
"INT_ABS_MUL_1",INT_ABS_MUL_1;
"INT_ABS_NEG",INT_ABS_NEG;
"INT_ABS_NUM",INT_ABS_NUM;
"INT_ABS_NZ",INT_ABS_NZ;
"INT_ABS_POS",INT_ABS_POS;
"INT_ABS_POW",INT_ABS_POW;
"INT_ABS_REFL",INT_ABS_REFL;
"INT_ABS_SGN",INT_ABS_SGN;
"INT_ABS_SIGN",INT_ABS_SIGN;
"INT_ABS_SIGN2",INT_ABS_SIGN2;
"INT_ABS_STILLNZ",INT_ABS_STILLNZ;
"INT_ABS_SUB",INT_ABS_SUB;
"INT_ABS_SUB_ABS",INT_ABS_SUB_ABS;
"INT_ABS_TRIANGLE",INT_ABS_TRIANGLE;
"INT_ABS_ZERO",INT_ABS_ZERO;
"INT_ADD2_SUB2",INT_ADD2_SUB2;
"INT_ADD_AC",INT_ADD_AC;
"INT_ADD_ASSOC",INT_ADD_ASSOC;
"INT_ADD_LDISTRIB",INT_ADD_LDISTRIB;
"INT_ADD_LID",INT_ADD_LID;
"INT_ADD_LINV",INT_ADD_LINV;
"INT_ADD_RDISTRIB",INT_ADD_RDISTRIB;
"INT_ADD_REM",INT_ADD_REM;
"INT_ADD_RID",INT_ADD_RID;
"INT_ADD_RINV",INT_ADD_RINV;
"INT_ADD_SUB",INT_ADD_SUB;
"INT_ADD_SUB2",INT_ADD_SUB2;
"INT_ADD_SYM",INT_ADD_SYM;
"INT_ARCH",INT_ARCH;
"INT_BOUNDS_LE",INT_BOUNDS_LE;
"INT_BOUNDS_LT",INT_BOUNDS_LT;
"INT_CONG_DIV2",INT_CONG_DIV2;
"INT_CONG_IMP_EQ",INT_CONG_IMP_EQ;
"INT_CONG_LREM",INT_CONG_LREM;
"INT_CONG_NUM_EXISTS",INT_CONG_NUM_EXISTS;
"INT_CONG_RREM",INT_CONG_RREM;
"INT_CONG_SOLVE_BOUNDS",INT_CONG_SOLVE_BOUNDS;
"INT_DIFFSQ",INT_DIFFSQ;
"INT_DIVIDES_ABS",INT_DIVIDES_ABS;
"INT_DIVIDES_DIVIDES_DIV",INT_DIVIDES_DIVIDES_DIV;
"INT_DIVIDES_DIVIDES_DIV_EQ",INT_DIVIDES_DIVIDES_DIV_EQ;
"INT_DIVIDES_DIV_DIVIDES",INT_DIVIDES_DIV_DIVIDES;
"INT_DIVIDES_DIV_SELF",INT_DIVIDES_DIV_SELF;
"INT_DIVIDES_LABS",INT_DIVIDES_LABS;
"INT_DIVIDES_LCM_GCD",INT_DIVIDES_LCM_GCD;
"INT_DIVIDES_LE",INT_DIVIDES_LE;
"INT_DIVIDES_RABS",INT_DIVIDES_RABS;
"INT_DIVISION",INT_DIVISION;
"INT_DIVISION_0",INT_DIVISION_0;
"INT_DIVISION_SIMP",INT_DIVISION_SIMP;
"INT_DIVMOD_EXIST_0",INT_DIVMOD_EXIST_0;
"INT_DIVMOD_UNIQ",INT_DIVMOD_UNIQ;
"INT_DIV_0",INT_DIV_0;
"INT_DIV_1",INT_DIV_1;
"INT_DIV_BY_DIV",INT_DIV_BY_DIV;
"INT_DIV_DIV",INT_DIV_DIV;
"INT_DIV_EQ_0",INT_DIV_EQ_0;
"INT_DIV_LE",INT_DIV_LE;
"INT_DIV_LE_EQ",INT_DIV_LE_EQ;
"INT_DIV_LNEG",INT_DIV_LNEG;
"INT_DIV_LT",INT_DIV_LT;
"INT_DIV_LT_EQ",INT_DIV_LT_EQ;
"INT_DIV_MUL",INT_DIV_MUL;
"INT_DIV_MUL_ADD",INT_DIV_MUL_ADD;
"INT_DIV_NEG2",INT_DIV_NEG2;
"INT_DIV_REFL",INT_DIV_REFL;
"INT_DIV_REM",INT_DIV_REM;
"INT_DIV_RNEG",INT_DIV_RNEG;
"INT_DIV_UNIQ",INT_DIV_UNIQ;
"INT_DIV_ZERO",INT_DIV_ZERO;
"INT_ENTIRE",INT_ENTIRE;
"INT_EQ_ADD_LCANCEL",INT_EQ_ADD_LCANCEL;
"INT_EQ_ADD_LCANCEL_0",INT_EQ_ADD_LCANCEL_0;
"INT_EQ_ADD_RCANCEL",INT_EQ_ADD_RCANCEL;
"INT_EQ_ADD_RCANCEL_0",INT_EQ_ADD_RCANCEL_0;
"INT_EQ_IMP_LE",INT_EQ_IMP_LE;
"INT_EQ_LCANCEL_IMP",INT_EQ_LCANCEL_IMP;
"INT_EQ_MUL_LCANCEL",INT_EQ_MUL_LCANCEL;
"INT_EQ_MUL_RCANCEL",INT_EQ_MUL_RCANCEL;
"INT_EQ_NEG2",INT_EQ_NEG2;
"INT_EQ_RCANCEL_IMP",INT_EQ_RCANCEL_IMP;
"INT_EQ_SGN_ABS",INT_EQ_SGN_ABS;
"INT_EQ_SQUARE_ABS",INT_EQ_SQUARE_ABS;
"INT_EQ_SUB_LADD",INT_EQ_SUB_LADD;
"INT_EQ_SUB_RADD",INT_EQ_SUB_RADD;
"INT_EVENPOW_ABS",INT_EVENPOW_ABS;
"INT_EXISTS_ABS",INT_EXISTS_ABS;
"INT_EXISTS_POS",INT_EXISTS_POS;
"INT_FORALL_ABS",INT_FORALL_ABS;
"INT_FORALL_POS",INT_FORALL_POS;
"INT_GCD_EXISTS",INT_GCD_EXISTS;
"INT_GCD_EXISTS_POS",INT_GCD_EXISTS_POS;
"INT_GE",INT_GE;
"INT_GT",INT_GT;
"INT_GT_DISCRETE",INT_GT_DISCRETE;
"INT_IMAGE",INT_IMAGE;
"INT_LCM",INT_LCM;
"INT_LCM_DIVIDES",INT_LCM_DIVIDES;
"INT_LCM_POS",INT_LCM_POS;
"INT_LET_ADD",INT_LET_ADD;
"INT_LET_ADD2",INT_LET_ADD2;
"INT_LET_ANTISYM",INT_LET_ANTISYM;
"INT_LET_TOTAL",INT_LET_TOTAL;
"INT_LET_TRANS",INT_LET_TRANS;
"INT_LE_01",INT_LE_01;
"INT_LE_ADD",INT_LE_ADD;
"INT_LE_ADD2",INT_LE_ADD2;
"INT_LE_ADDL",INT_LE_ADDL;
"INT_LE_ADDR",INT_LE_ADDR;
"INT_LE_ANTISYM",INT_LE_ANTISYM;
"INT_LE_DISCRETE",INT_LE_DISCRETE;
"INT_LE_DIV",INT_LE_DIV;
"INT_LE_DIV_EQ",INT_LE_DIV_EQ;
"INT_LE_DOUBLE",INT_LE_DOUBLE;
"INT_LE_LADD",INT_LE_LADD;
"INT_LE_LADD_IMP",INT_LE_LADD_IMP;
"INT_LE_LCANCEL_IMP",INT_LE_LCANCEL_IMP;
"INT_LE_LMUL",INT_LE_LMUL;
"INT_LE_LMUL_EQ",INT_LE_LMUL_EQ;
"INT_LE_LNEG",INT_LE_LNEG;
"INT_LE_LT",INT_LE_LT;
"INT_LE_MAX",INT_LE_MAX;
"INT_LE_MIN",INT_LE_MIN;
"INT_LE_MUL",INT_LE_MUL;
"INT_LE_MUL2",INT_LE_MUL2;
"INT_LE_MUL_EQ",INT_LE_MUL_EQ;
"INT_LE_NEG2",INT_LE_NEG2;
"INT_LE_NEGL",INT_LE_NEGL;
"INT_LE_NEGR",INT_LE_NEGR;
"INT_LE_NEGTOTAL",INT_LE_NEGTOTAL;
"INT_LE_POW2",INT_LE_POW2;
"INT_LE_POW_2",INT_LE_POW_2;
"INT_LE_RADD",INT_LE_RADD;
"INT_LE_RCANCEL_IMP",INT_LE_RCANCEL_IMP;
"INT_LE_REFL",INT_LE_REFL;
"INT_LE_RMUL",INT_LE_RMUL;
"INT_LE_RMUL_EQ",INT_LE_RMUL_EQ;
"INT_LE_RNEG",INT_LE_RNEG;
"INT_LE_SQUARE",INT_LE_SQUARE;
"INT_LE_SQUARE_ABS",INT_LE_SQUARE_ABS;
"INT_LE_SUB_LADD",INT_LE_SUB_LADD;
"INT_LE_SUB_RADD",INT_LE_SUB_RADD;
"INT_LE_TOTAL",INT_LE_TOTAL;
"INT_LE_TRANS",INT_LE_TRANS;
"INT_LE_TRANS_LE",INT_LE_TRANS_LE;
"INT_LE_TRANS_LT",INT_LE_TRANS_LT;
"INT_LNEG_UNIQ",INT_LNEG_UNIQ;
"INT_LT",INT_LT;
"INT_LTE_ADD",INT_LTE_ADD;
"INT_LTE_ADD2",INT_LTE_ADD2;
"INT_LTE_ANTISYM",INT_LTE_ANTISYM;
"INT_LTE_TOTAL",INT_LTE_TOTAL;
"INT_LTE_TRANS",INT_LTE_TRANS;
"INT_LT_01",INT_LT_01;
"INT_LT_ADD",INT_LT_ADD;
"INT_LT_ADD1",INT_LT_ADD1;
"INT_LT_ADD2",INT_LT_ADD2;
"INT_LT_ADDL",INT_LT_ADDL;
"INT_LT_ADDNEG",INT_LT_ADDNEG;
"INT_LT_ADDNEG2",INT_LT_ADDNEG2;
"INT_LT_ADDR",INT_LT_ADDR;
"INT_LT_ADD_SUB",INT_LT_ADD_SUB;
"INT_LT_ANTISYM",INT_LT_ANTISYM;
"INT_LT_DISCRETE",INT_LT_DISCRETE;
"INT_LT_DIV",INT_LT_DIV;
"INT_LT_DIV_EQ",INT_LT_DIV_EQ;
"INT_LT_GT",INT_LT_GT;
"INT_LT_IMP_LE",INT_LT_IMP_LE;
"INT_LT_IMP_NE",INT_LT_IMP_NE;
"INT_LT_LADD",INT_LT_LADD;
"INT_LT_LADD_IMP",INT_LT_LADD_IMP;
"INT_LT_LCANCEL_IMP",INT_LT_LCANCEL_IMP;
"INT_LT_LE",INT_LT_LE;
"INT_LT_LMUL",INT_LT_LMUL;
"INT_LT_LMUL_EQ",INT_LT_LMUL_EQ;
"INT_LT_LNEG",INT_LT_LNEG;
"INT_LT_MAX",INT_LT_MAX;
"INT_LT_MIN",INT_LT_MIN;
"INT_LT_MUL",INT_LT_MUL;
"INT_LT_MUL2",INT_LT_MUL2;
"INT_LT_MUL_EQ",INT_LT_MUL_EQ;
"INT_LT_NEG2",INT_LT_NEG2;
"INT_LT_NEGTOTAL",INT_LT_NEGTOTAL;
"INT_LT_POW2",INT_LT_POW2;
"INT_LT_POW_2",INT_LT_POW_2;
"INT_LT_RADD",INT_LT_RADD;
"INT_LT_RCANCEL_IMP",INT_LT_RCANCEL_IMP;
"INT_LT_REFL",INT_LT_REFL;
"INT_LT_REM",INT_LT_REM;
"INT_LT_REM_EQ",INT_LT_REM_EQ;
"INT_LT_RMUL",INT_LT_RMUL;
"INT_LT_RMUL_EQ",INT_LT_RMUL_EQ;
"INT_LT_RNEG",INT_LT_RNEG;
"INT_LT_SQUARE",INT_LT_SQUARE;
"INT_LT_SQUARE_ABS",INT_LT_SQUARE_ABS;
"INT_LT_SUB_LADD",INT_LT_SUB_LADD;
"INT_LT_SUB_RADD",INT_LT_SUB_RADD;
"INT_LT_TOTAL",INT_LT_TOTAL;
"INT_LT_TRANS",INT_LT_TRANS;
"INT_MAX",INT_MAX;
"INT_MAX_ACI",INT_MAX_ACI;
"INT_MAX_ASSOC",INT_MAX_ASSOC;
"INT_MAX_LE",INT_MAX_LE;
"INT_MAX_LT",INT_MAX_LT;
"INT_MAX_MAX",INT_MAX_MAX;
"INT_MAX_MIN",INT_MAX_MIN;
"INT_MAX_SYM",INT_MAX_SYM;
"INT_MIN",INT_MIN;
"INT_MIN_ACI",INT_MIN_ACI;
"INT_MIN_ASSOC",INT_MIN_ASSOC;
"INT_MIN_LE",INT_MIN_LE;
"INT_MIN_LT",INT_MIN_LT;
"INT_MIN_MAX",INT_MIN_MAX;
"INT_MIN_MIN",INT_MIN_MIN;
"INT_MIN_SYM",INT_MIN_SYM;
"INT_MUL_2",INT_MUL_2;
"INT_MUL_AC",INT_MUL_AC;
"INT_MUL_ASSOC",INT_MUL_ASSOC;
"INT_MUL_DIV_EQ",INT_MUL_DIV_EQ;
"INT_MUL_EQ_1",INT_MUL_EQ_1;
"INT_MUL_GCD_LCM",INT_MUL_GCD_LCM;
"INT_MUL_LCM_GCD",INT_MUL_LCM_GCD;
"INT_MUL_LID",INT_MUL_LID;
"INT_MUL_LNEG",INT_MUL_LNEG;
"INT_MUL_LZERO",INT_MUL_LZERO;
"INT_MUL_POS_LE",INT_MUL_POS_LE;
"INT_MUL_POS_LT",INT_MUL_POS_LT;
"INT_MUL_REM",INT_MUL_REM;
"INT_MUL_RID",INT_MUL_RID;
"INT_MUL_RNEG",INT_MUL_RNEG;
"INT_MUL_RZERO",INT_MUL_RZERO;
"INT_MUL_SYM",INT_MUL_SYM;
"INT_NEG_0",INT_NEG_0;
"INT_NEG_ADD",INT_NEG_ADD;
"INT_NEG_EQ",INT_NEG_EQ;
"INT_NEG_EQ_0",INT_NEG_EQ_0;
"INT_NEG_GE0",INT_NEG_GE0;
"INT_NEG_GT0",INT_NEG_GT0;
"INT_NEG_LE0",INT_NEG_LE0;
"INT_NEG_LMUL",INT_NEG_LMUL;
"INT_NEG_LT0",INT_NEG_LT0;
"INT_NEG_MINUS1",INT_NEG_MINUS1;
"INT_NEG_MUL2",INT_NEG_MUL2;
"INT_NEG_NEG",INT_NEG_NEG;
"INT_NEG_REM",INT_NEG_REM;
"INT_NEG_RMUL",INT_NEG_RMUL;
"INT_NEG_SUB",INT_NEG_SUB;
"INT_NOT_EQ",INT_NOT_EQ;
"INT_NOT_LE",INT_NOT_LE;
"INT_NOT_LT",INT_NOT_LT;
"INT_OF_NUM_ADD",INT_OF_NUM_ADD;
"INT_OF_NUM_CLAUSES",INT_OF_NUM_CLAUSES;
"INT_OF_NUM_DIV",INT_OF_NUM_DIV;
"INT_OF_NUM_EQ",INT_OF_NUM_EQ;
"INT_OF_NUM_EXISTS",INT_OF_NUM_EXISTS;
"INT_OF_NUM_GE",INT_OF_NUM_GE;
"INT_OF_NUM_GT",INT_OF_NUM_GT;
"INT_OF_NUM_LE",INT_OF_NUM_LE;
"INT_OF_NUM_LT",INT_OF_NUM_LT;
"INT_OF_NUM_MAX",INT_OF_NUM_MAX;
"INT_OF_NUM_MIN",INT_OF_NUM_MIN;
"INT_OF_NUM_MOD",INT_OF_NUM_MOD;
"INT_OF_NUM_MUL",INT_OF_NUM_MUL;
"INT_OF_NUM_OF_INT",INT_OF_NUM_OF_INT;
"INT_OF_NUM_POW",INT_OF_NUM_POW;
"INT_OF_NUM_REM",INT_OF_NUM_REM;
"INT_OF_NUM_SUB",INT_OF_NUM_SUB;
"INT_OF_NUM_SUB_CASES",INT_OF_NUM_SUB_CASES;
"INT_OF_NUM_SUC",INT_OF_NUM_SUC;
"INT_POS",INT_POS;
"INT_POS_EQ_SQUARE",INT_POS_EQ_SQUARE;
"INT_POS_NZ",INT_POS_NZ;
"INT_POW",INT_POW;
"INT_POW2_ABS",INT_POW2_ABS;
"INT_POW_1",INT_POW_1;
"INT_POW_1_LE",INT_POW_1_LE;
"INT_POW_1_LT",INT_POW_1_LT;
"INT_POW_2",INT_POW_2;
"INT_POW_ADD",INT_POW_ADD;
"INT_POW_EQ",INT_POW_EQ;
"INT_POW_EQ_0",INT_POW_EQ_0;
"INT_POW_EQ_1",INT_POW_EQ_1;
"INT_POW_EQ_1_IMP",INT_POW_EQ_1_IMP;
"INT_POW_EQ_ABS",INT_POW_EQ_ABS;
"INT_POW_EQ_EQ",INT_POW_EQ_EQ;
"INT_POW_EQ_ODD",INT_POW_EQ_ODD;
"INT_POW_EQ_ODD_EQ",INT_POW_EQ_ODD_EQ;
"INT_POW_LBOUND",INT_POW_LBOUND;
"INT_POW_LE",INT_POW_LE;
"INT_POW_LE2",INT_POW_LE2;
"INT_POW_LE2_ODD",INT_POW_LE2_ODD;
"INT_POW_LE2_ODD_EQ",INT_POW_LE2_ODD_EQ;
"INT_POW_LE2_REV",INT_POW_LE2_REV;
"INT_POW_LE_1",INT_POW_LE_1;
"INT_POW_LT",INT_POW_LT;
"INT_POW_LT2",INT_POW_LT2;
"INT_POW_LT2_ODD",INT_POW_LT2_ODD;
"INT_POW_LT2_ODD_EQ",INT_POW_LT2_ODD_EQ;
"INT_POW_LT2_REV",INT_POW_LT2_REV;
"INT_POW_LT_1",INT_POW_LT_1;
"INT_POW_MONO",INT_POW_MONO;
"INT_POW_MONO_LT",INT_POW_MONO_LT;
"INT_POW_MUL",INT_POW_MUL;
"INT_POW_NEG",INT_POW_NEG;
"INT_POW_NZ",INT_POW_NZ;
"INT_POW_ONE",INT_POW_ONE;
"INT_POW_POW",INT_POW_POW;
"INT_POW_REM",INT_POW_REM;
"INT_POW_ZERO",INT_POW_ZERO;
"INT_REM_0",INT_REM_0;
"INT_REM_1",INT_REM_1;
"INT_REM_2_CASES",INT_REM_2_CASES;
"INT_REM_2_DIVIDES",INT_REM_2_DIVIDES;
"INT_REM_2_EXPAND",INT_REM_2_EXPAND;
"INT_REM_2_NEG",INT_REM_2_NEG;
"INT_REM_DIV",INT_REM_DIV;
"INT_REM_EQ",INT_REM_EQ;
"INT_REM_EQ_0",INT_REM_EQ_0;
"INT_REM_EQ_SELF",INT_REM_EQ_SELF;
"INT_REM_LE",INT_REM_LE;
"INT_REM_LE_EQ",INT_REM_LE_EQ;
"INT_REM_LNEG",INT_REM_LNEG;
"INT_REM_LT",INT_REM_LT;
"INT_REM_MOD_SELF",INT_REM_MOD_SELF;
"INT_REM_MUL",INT_REM_MUL;
"INT_REM_MUL_ADD",INT_REM_MUL_ADD;
"INT_REM_MUL_REM",INT_REM_MUL_REM;
"INT_REM_NEG2",INT_REM_NEG2;
"INT_REM_POS",INT_REM_POS;
"INT_REM_POS_EQ",INT_REM_POS_EQ;
"INT_REM_RABS",INT_REM_RABS;
"INT_REM_REFL",INT_REM_REFL;
"INT_REM_REM",INT_REM_REM;
"INT_REM_REM_LE",INT_REM_REM_LE;
"INT_REM_REM_MUL",INT_REM_REM_MUL;
"INT_REM_REM_POW_MIN",INT_REM_REM_POW_MIN;
"INT_REM_RNEG",INT_REM_RNEG;
"INT_REM_UNIQ",INT_REM_UNIQ;
"INT_REM_UNIQUE",INT_REM_UNIQUE;
"INT_REM_ZERO",INT_REM_ZERO;
"INT_RNEG_UNIQ",INT_RNEG_UNIQ;
"INT_SGN",INT_SGN;
"INT_SGNS_EQ",INT_SGNS_EQ;
"INT_SGNS_EQ_ALT",INT_SGNS_EQ_ALT;
"INT_SGN_0",INT_SGN_0;
"INT_SGN_ABS",INT_SGN_ABS;
"INT_SGN_ABS_ALT",INT_SGN_ABS_ALT;
"INT_SGN_CASES",INT_SGN_CASES;
"INT_SGN_EQ",INT_SGN_EQ;
"INT_SGN_EQ_INEQ",INT_SGN_EQ_INEQ;
"INT_SGN_INEQS",INT_SGN_INEQS;
"INT_SGN_INT_SGN",INT_SGN_INT_SGN;
"INT_SGN_MUL",INT_SGN_MUL;
"INT_SGN_NEG",INT_SGN_NEG;
"INT_SGN_POW",INT_SGN_POW;
"INT_SGN_POW_2",INT_SGN_POW_2;
"INT_SOS_EQ_0",INT_SOS_EQ_0;
"INT_SUB",INT_SUB;
"INT_SUB_0",INT_SUB_0;
"INT_SUB_ABS",INT_SUB_ABS;
"INT_SUB_ADD",INT_SUB_ADD;
"INT_SUB_ADD2",INT_SUB_ADD2;
"INT_SUB_LDISTRIB",INT_SUB_LDISTRIB;
"INT_SUB_LE",INT_SUB_LE;
"INT_SUB_LNEG",INT_SUB_LNEG;
"INT_SUB_LT",INT_SUB_LT;
"INT_SUB_LZERO",INT_SUB_LZERO;
"INT_SUB_NEG2",INT_SUB_NEG2;
"INT_SUB_RDISTRIB",INT_SUB_RDISTRIB;
"INT_SUB_REFL",INT_SUB_REFL;
"INT_SUB_REM",INT_SUB_REM;
"INT_SUB_RNEG",INT_SUB_RNEG;
"INT_SUB_RZERO",INT_SUB_RZERO;
"INT_SUB_SUB",INT_SUB_SUB;
"INT_SUB_SUB2",INT_SUB_SUB2;
"INT_SUB_TRIANGLE",INT_SUB_TRIANGLE;
"INT_WLOG_LE",INT_WLOG_LE;
"INT_WLOG_LE_3",INT_WLOG_LE_3;
"INT_WLOG_LT",INT_WLOG_LT;
"INT_WOP",INT_WOP;
"INVOLUTION_EVEN_FIXPOINTS",INVOLUTION_EVEN_FIXPOINTS;
"INVOLUTION_EVEN_NOFIXPOINTS",INVOLUTION_EVEN_NOFIXPOINTS;
"IN_CARTESIAN_PRODUCT",IN_CARTESIAN_PRODUCT;
"IN_CROSS",IN_CROSS;
"IN_DELETE",IN_DELETE;
"IN_DELETE_EQ",IN_DELETE_EQ;
"IN_DIFF",IN_DIFF;
"IN_DISJOINT",IN_DISJOINT;
"IN_ELIM_PAIR_THM",IN_ELIM_PAIR_THM;
"IN_ELIM_PASTECART_THM",IN_ELIM_PASTECART_THM;
"IN_ELIM_QUAD_THM",IN_ELIM_QUAD_THM;
"IN_ELIM_THM",IN_ELIM_THM;
"IN_ELIM_TRIPLE_THM",IN_ELIM_TRIPLE_THM;
"IN_EXTENSIONAL",IN_EXTENSIONAL;
"IN_EXTENSIONAL_UNDEFINED",IN_EXTENSIONAL_UNDEFINED;
"IN_GSPEC",IN_GSPEC;
"IN_IMAGE",IN_IMAGE;
"IN_INSERT",IN_INSERT;
"IN_INTER",IN_INTER;
"IN_INTERS",IN_INTERS;
"IN_NUMSEG",IN_NUMSEG;
"IN_NUMSEG_0",IN_NUMSEG_0;
"IN_REST",IN_REST;
"IN_SET_OF_LIST",IN_SET_OF_LIST;
"IN_SING",IN_SING;
"IN_SUPPORT",IN_SUPPORT;
"IN_UNION",IN_UNION;
"IN_UNIONS",IN_UNIONS;
"IN_UNIV",IN_UNIV;
"IPRODUCT_CLAUSES",IPRODUCT_CLAUSES;
"ISO",ISO;
"ISO_FUN",ISO_FUN;
"ISO_REFL",ISO_REFL;
"ISO_USAGE",ISO_USAGE;
"ISUM_CLAUSES",ISUM_CLAUSES;
"ITERATE_BIJECTION",ITERATE_BIJECTION;
"ITERATE_CASES",ITERATE_CASES;
"ITERATE_CLAUSES",ITERATE_CLAUSES;
"ITERATE_CLAUSES_GEN",ITERATE_CLAUSES_GEN;
"ITERATE_CLAUSES_NUMSEG",ITERATE_CLAUSES_NUMSEG;
"ITERATE_CLAUSES_NUMSEG_LE",ITERATE_CLAUSES_NUMSEG_LE;
"ITERATE_CLAUSES_NUMSEG_LT",ITERATE_CLAUSES_NUMSEG_LT;
"ITERATE_CLOSED",ITERATE_CLOSED;
"ITERATE_CLOSED_NONEMPTY",ITERATE_CLOSED_NONEMPTY;
"ITERATE_DELETE",ITERATE_DELETE;
"ITERATE_DELTA",ITERATE_DELTA;
"ITERATE_DIFF",ITERATE_DIFF;
"ITERATE_DIFF_GEN",ITERATE_DIFF_GEN;
"ITERATE_EQ",ITERATE_EQ;
"ITERATE_EQ_GENERAL",ITERATE_EQ_GENERAL;
"ITERATE_EQ_GENERAL_INVERSES",ITERATE_EQ_GENERAL_INVERSES;
"ITERATE_EQ_NEUTRAL",ITERATE_EQ_NEUTRAL;
"ITERATE_EXPAND_CASES",ITERATE_EXPAND_CASES;
"ITERATE_IMAGE",ITERATE_IMAGE;
"ITERATE_IMAGE_GEN",ITERATE_IMAGE_GEN;
"ITERATE_IMAGE_NONZERO",ITERATE_IMAGE_NONZERO;
"ITERATE_INCL_EXCL",ITERATE_INCL_EXCL;
"ITERATE_INJECTION",ITERATE_INJECTION;
"ITERATE_ITERATE_PRODUCT",ITERATE_ITERATE_PRODUCT;
"ITERATE_OP",ITERATE_OP;
"ITERATE_OP_GEN",ITERATE_OP_GEN;
"ITERATE_PAIR",ITERATE_PAIR;
"ITERATE_REFLECT",ITERATE_REFLECT;
"ITERATE_RELATED",ITERATE_RELATED;
"ITERATE_RELATED_NONEMPTY",ITERATE_RELATED_NONEMPTY;
"ITERATE_RESTRICT_SET",ITERATE_RESTRICT_SET;
"ITERATE_SING",ITERATE_SING;
"ITERATE_SUPERSET",ITERATE_SUPERSET;
"ITERATE_SUPPORT",ITERATE_SUPPORT;
"ITERATE_SWAP",ITERATE_SWAP;
"ITERATE_UNION",ITERATE_UNION;
"ITERATE_UNION_GEN",ITERATE_UNION_GEN;
"ITERATE_UNION_NONZERO",ITERATE_UNION_NONZERO;
"ITERATE_UNIV",ITERATE_UNIV;
"ITERATO_CLAUSES",ITERATO_CLAUSES;
"ITERATO_CLAUSES_EXISTS",ITERATO_CLAUSES_EXISTS;
"ITERATO_CLAUSES_GEN",ITERATO_CLAUSES_GEN;
"ITERATO_CLAUSES_NUMSEG_LEFT",ITERATO_CLAUSES_NUMSEG_LEFT;
"ITERATO_CLOSED",ITERATO_CLOSED;
"ITERATO_EQ",ITERATO_EQ;
"ITERATO_EXPAND_CASES",ITERATO_EXPAND_CASES;
"ITERATO_INDUCT",ITERATO_INDUCT;
"ITERATO_ITERATE",ITERATO_ITERATE;
"ITERATO_SUPPORT",ITERATO_SUPPORT;
"ITLIST",ITLIST;
"ITLIST2",ITLIST2;
"ITLIST2_DEF",ITLIST2_DEF;
"ITLIST_APPEND",ITLIST_APPEND;
"ITLIST_EXTRA",ITLIST_EXTRA;
"ITSET",ITSET;
"ITSET_EQ",ITSET_EQ;
"I_DEF",I_DEF;
"I_O_ID",I_O_ID;
"I_THM",I_THM;
"LAMBDA_BETA",LAMBDA_BETA;
"LAMBDA_ETA",LAMBDA_ETA;
"LAMBDA_PAIR",LAMBDA_PAIR;
"LAMBDA_PAIR_THM",LAMBDA_PAIR_THM;
"LAMBDA_TRIPLE",LAMBDA_TRIPLE;
"LAMBDA_TRIPLE_THM",LAMBDA_TRIPLE_THM;
"LAMBDA_UNIQUE",LAMBDA_UNIQUE;
"LAST",LAST;
"LAST_APPEND",LAST_APPEND;
"LAST_CLAUSES",LAST_CLAUSES;
"LAST_EL",LAST_EL;
"LAST_REVERSE",LAST_REVERSE;
"LDIV_LT_EQ",LDIV_LT_EQ;
"LE",LE;
"LEFT_ADD_DISTRIB",LEFT_ADD_DISTRIB;
"LEFT_AND_EXISTS_THM",LEFT_AND_EXISTS_THM;
"LEFT_AND_FORALL_THM",LEFT_AND_FORALL_THM;
"LEFT_EXISTS_AND_THM",LEFT_EXISTS_AND_THM;
"LEFT_EXISTS_IMP_THM",LEFT_EXISTS_IMP_THM;
"LEFT_FORALL_IMP_THM",LEFT_FORALL_IMP_THM;
"LEFT_FORALL_OR_THM",LEFT_FORALL_OR_THM;
"LEFT_IMP_EXISTS_THM",LEFT_IMP_EXISTS_THM;
"LEFT_IMP_FORALL_THM",LEFT_IMP_FORALL_THM;
"LEFT_OR_DISTRIB",LEFT_OR_DISTRIB;
"LEFT_OR_EXISTS_THM",LEFT_OR_EXISTS_THM;
"LEFT_OR_FORALL_THM",LEFT_OR_FORALL_THM;
"LEFT_SUB_DISTRIB",LEFT_SUB_DISTRIB;
"LENGTH",LENGTH;
"LENGTH_APPEND",LENGTH_APPEND;
"LENGTH_EQ_CONS",LENGTH_EQ_CONS;
"LENGTH_EQ_NIL",LENGTH_EQ_NIL;
"LENGTH_LIST_OF_SEQ",LENGTH_LIST_OF_SEQ;
"LENGTH_LIST_OF_SET",LENGTH_LIST_OF_SET;
"LENGTH_MAP",LENGTH_MAP;
"LENGTH_MAP2",LENGTH_MAP2;
"LENGTH_REPLICATE",LENGTH_REPLICATE;
"LENGTH_REVERSE",LENGTH_REVERSE;
"LENGTH_TL",LENGTH_TL;
"LENGTH_ZIP",LENGTH_ZIP;
"LET_ADD2",LET_ADD2;
"LET_ANTISYM",LET_ANTISYM;
"LET_CASES",LET_CASES;
"LET_DEF",LET_DEF;
"LET_END_DEF",LET_END_DEF;
"LET_TRANS",LET_TRANS;
"LE_0",LE_0;
"LE_1",LE_1;
"LE_ADD",LE_ADD;
"LE_ADD2",LE_ADD2;
"LE_ADDR",LE_ADDR;
"LE_ADD_LCANCEL",LE_ADD_LCANCEL;
"LE_ADD_RCANCEL",LE_ADD_RCANCEL;
"LE_ANTISYM",LE_ANTISYM;
"LE_C",LE_C;
"LE_CASES",LE_CASES;
"LE_EXISTS",LE_EXISTS;
"LE_EXP",LE_EXP;
"LE_INDUCT",LE_INDUCT;
"LE_LDIV",LE_LDIV;
"LE_LDIV_EQ",LE_LDIV_EQ;
"LE_LT",LE_LT;
"LE_MINIMAL",LE_MINIMAL;
"LE_MULT2",LE_MULT2;
"LE_MULT_LCANCEL",LE_MULT_LCANCEL;
"LE_MULT_RCANCEL",LE_MULT_RCANCEL;
"LE_RDIV_EQ",LE_RDIV_EQ;
"LE_REFL",LE_REFL;
"LE_SQUARE_REFL",LE_SQUARE_REFL;
"LE_SUC",LE_SUC;
"LE_SUC_LT",LE_SUC_LT;
"LE_TRANS",LE_TRANS;
"LIST_EQ",LIST_EQ;
"LIST_OF_SEQ_EQ_NIL",LIST_OF_SEQ_EQ_NIL;
"LIST_OF_SET_EMPTY",LIST_OF_SET_EMPTY;
"LIST_OF_SET_PROPERTIES",LIST_OF_SET_PROPERTIES;
"LIST_OF_SET_SING",LIST_OF_SET_SING;
"LT",LT;
"LTE_ADD2",LTE_ADD2;
"LTE_ANTISYM",LTE_ANTISYM;
"LTE_CASES",LTE_CASES;
"LTE_TRANS",LTE_TRANS;
"LT_0",LT_0;
"LT_ADD",LT_ADD;
"LT_ADD2",LT_ADD2;
"LT_ADDR",LT_ADDR;
"LT_ADD_LCANCEL",LT_ADD_LCANCEL;
"LT_ADD_RCANCEL",LT_ADD_RCANCEL;
"LT_ANTISYM",LT_ANTISYM;
"LT_CASES",LT_CASES;
"LT_EXISTS",LT_EXISTS;
"LT_EXP",LT_EXP;
"LT_IMP_LE",LT_IMP_LE;
"LT_IMP_NE",LT_IMP_NE;
"LT_LE",LT_LE;
"LT_LMULT",LT_LMULT;
"LT_MULT",LT_MULT;
"LT_MULT2",LT_MULT2;
"LT_MULT_LCANCEL",LT_MULT_LCANCEL;
"LT_MULT_RCANCEL",LT_MULT_RCANCEL;
"LT_NZ",LT_NZ;
"LT_POW2_REFL",LT_POW2_REFL;
"LT_REFL",LT_REFL;
"LT_SUC",LT_SUC;
"LT_SUC_LE",LT_SUC_LE;
"LT_TRANS",LT_TRANS;
"MAP",MAP;
"MAP2",MAP2;
"MAP2_DEF",MAP2_DEF;
"MAP_APPEND",MAP_APPEND;
"MAP_EQ",MAP_EQ;
"MAP_EQ_ALL2",MAP_EQ_ALL2;
"MAP_EQ_DEGEN",MAP_EQ_DEGEN;
"MAP_EQ_NIL",MAP_EQ_NIL;
"MAP_FST_ZIP",MAP_FST_ZIP;
"MAP_I",MAP_I;
"MAP_ID",MAP_ID;
"MAP_REVERSE",MAP_REVERSE;
"MAP_SND_ZIP",MAP_SND_ZIP;
"MAP_o",MAP_o;
"MATCH_SEQPATTERN",MATCH_SEQPATTERN;
"MAX",MAX;
"MEASURE",MEASURE;
"MEASURE_LE",MEASURE_LE;
"MEM",MEM;
"MEMBER_NOT_EMPTY",MEMBER_NOT_EMPTY;
"MEM_APPEND",MEM_APPEND;
"MEM_APPEND_DECOMPOSE",MEM_APPEND_DECOMPOSE;
"MEM_APPEND_DECOMPOSE_LEFT",MEM_APPEND_DECOMPOSE_LEFT;
"MEM_ASSOC",MEM_ASSOC;
"MEM_EL",MEM_EL;
"MEM_EXISTS_EL",MEM_EXISTS_EL;
"MEM_FILTER",MEM_FILTER;
"MEM_LIST_OF_SET",MEM_LIST_OF_SET;
"MEM_MAP",MEM_MAP;
"MEM_REPLICATE",MEM_REPLICATE;
"MIN",MIN;
"MINIMAL",MINIMAL;
"MINIMAL_BAD_SEQUENCE",MINIMAL_BAD_SEQUENCE;
"MINIMAL_LBOUND",MINIMAL_LBOUND;
"MINIMAL_LE",MINIMAL_LE;
"MINIMAL_MONO",MINIMAL_MONO;
"MINIMAL_UBOUND",MINIMAL_UBOUND;
"MINIMAL_UNIQUE",MINIMAL_UNIQUE;
"MK_REC_INJ",MK_REC_INJ;
"MOD_0",MOD_0;
"MOD_1",MOD_1;
"MOD_2_CASES",MOD_2_CASES;
"MOD_ADD_CASES",MOD_ADD_CASES;
"MOD_ADD_EQ",MOD_ADD_EQ;
"MOD_ADD_EQ_EQ",MOD_ADD_EQ_EQ;
"MOD_ADD_MOD",MOD_ADD_MOD;
"MOD_CASES",MOD_CASES;
"MOD_DIV_EQ_0",MOD_DIV_EQ_0;
"MOD_EQ",MOD_EQ;
"MOD_EQ_0",MOD_EQ_0;
"MOD_EQ_SELF",MOD_EQ_SELF;
"MOD_EVEN_2",MOD_EVEN_2;
"MOD_EXISTS",MOD_EXISTS;
"MOD_EXP",MOD_EXP;
"MOD_EXP_MOD",MOD_EXP_MOD;
"MOD_LE",MOD_LE;
"MOD_LE_TWICE",MOD_LE_TWICE;
"MOD_LT",MOD_LT;
"MOD_LT_EQ",MOD_LT_EQ;
"MOD_LT_EQ_LT",MOD_LT_EQ_LT;
"MOD_MOD",MOD_MOD;
"MOD_MOD_EXP_MIN",MOD_MOD_EXP_MIN;
"MOD_MOD_LE",MOD_MOD_LE;
"MOD_MOD_REFL",MOD_MOD_REFL;
"MOD_MULT",MOD_MULT;
"MOD_MULT2",MOD_MULT2;
"MOD_MULT_ADD",MOD_MULT_ADD;
"MOD_MULT_LMOD",MOD_MULT_LMOD;
"MOD_MULT_MOD",MOD_MULT_MOD;
"MOD_MULT_MOD2",MOD_MULT_MOD2;
"MOD_MULT_RMOD",MOD_MULT_RMOD;
"MOD_NSUM_MOD",MOD_NSUM_MOD;
"MOD_NSUM_MOD_NUMSEG",MOD_NSUM_MOD_NUMSEG;
"MOD_REFL",MOD_REFL;
"MOD_UNIQ",MOD_UNIQ;
"MOD_ZERO",MOD_ZERO;
"MONOIDAL_AC",MONOIDAL_AC;
"MONOIDAL_ADD",MONOIDAL_ADD;
"MONOIDAL_INT_ADD",MONOIDAL_INT_ADD;
"MONOIDAL_INT_MUL",MONOIDAL_INT_MUL;
"MONOIDAL_MUL",MONOIDAL_MUL;
"MONOIDAL_REAL_ADD",MONOIDAL_REAL_ADD;
"MONOIDAL_REAL_MUL",MONOIDAL_REAL_MUL;
"MONO_ALL",MONO_ALL;
"MONO_ALL2",MONO_ALL2;
"MONO_AND",MONO_AND;
"MONO_COND",MONO_COND;
"MONO_EXISTS",MONO_EXISTS;
"MONO_FORALL",MONO_FORALL;
"MONO_IMP",MONO_IMP;
"MONO_NOT",MONO_NOT;
"MONO_OR",MONO_OR;
"MULT",MULT;
"MULT_0",MULT_0;
"MULT_2",MULT_2;
"MULT_AC",MULT_AC;
"MULT_ASSOC",MULT_ASSOC;
"MULT_CLAUSES",MULT_CLAUSES;
"MULT_DIV",MULT_DIV;
"MULT_DIV_LE",MULT_DIV_LE;
"MULT_EQ_0",MULT_EQ_0;
"MULT_EQ_1",MULT_EQ_1;
"MULT_EXP",MULT_EXP;
"MULT_SUC",MULT_SUC;
"MULT_SYM",MULT_SYM;
"NADD_ADD",NADD_ADD;
"NADD_ADDITIVE",NADD_ADDITIVE;
"NADD_ADD_ASSOC",NADD_ADD_ASSOC;
"NADD_ADD_LCANCEL",NADD_ADD_LCANCEL;
"NADD_ADD_LID",NADD_ADD_LID;
"NADD_ADD_SYM",NADD_ADD_SYM;
"NADD_ADD_WELLDEF",NADD_ADD_WELLDEF;
"NADD_ALTMUL",NADD_ALTMUL;
"NADD_ARCH",NADD_ARCH;
"NADD_ARCH_LEMMA",NADD_ARCH_LEMMA;
"NADD_ARCH_MULT",NADD_ARCH_MULT;
"NADD_ARCH_ZERO",NADD_ARCH_ZERO;
"NADD_BOUND",NADD_BOUND;
"NADD_CAUCHY",NADD_CAUCHY;
"NADD_COMPLETE",NADD_COMPLETE;
"NADD_DIST",NADD_DIST;
"NADD_DIST_LEMMA",NADD_DIST_LEMMA;
"NADD_EQ_IMP_LE",NADD_EQ_IMP_LE;
"NADD_EQ_REFL",NADD_EQ_REFL;
"NADD_EQ_SYM",NADD_EQ_SYM;
"NADD_EQ_TRANS",NADD_EQ_TRANS;
"NADD_INV",NADD_INV;
"NADD_INV_0",NADD_INV_0;
"NADD_INV_WELLDEF",NADD_INV_WELLDEF;
"NADD_LBOUND",NADD_LBOUND;
"NADD_LDISTRIB",NADD_LDISTRIB;
"NADD_LE_0",NADD_LE_0;
"NADD_LE_ADD",NADD_LE_ADD;
"NADD_LE_ANTISYM",NADD_LE_ANTISYM;
"NADD_LE_EXISTS",NADD_LE_EXISTS;
"NADD_LE_LADD",NADD_LE_LADD;
"NADD_LE_LMUL",NADD_LE_LMUL;
"NADD_LE_RADD",NADD_LE_RADD;
"NADD_LE_REFL",NADD_LE_REFL;
"NADD_LE_RMUL",NADD_LE_RMUL;
"NADD_LE_TOTAL",NADD_LE_TOTAL;
"NADD_LE_TOTAL_LEMMA",NADD_LE_TOTAL_LEMMA;
"NADD_LE_TRANS",NADD_LE_TRANS;
"NADD_LE_WELLDEF",NADD_LE_WELLDEF;
"NADD_LE_WELLDEF_LEMMA",NADD_LE_WELLDEF_LEMMA;
"NADD_MUL",NADD_MUL;
"NADD_MULTIPLICATIVE",NADD_MULTIPLICATIVE;
"NADD_MUL_ASSOC",NADD_MUL_ASSOC;
"NADD_MUL_LID",NADD_MUL_LID;
"NADD_MUL_LINV",NADD_MUL_LINV;
"NADD_MUL_LINV_LEMMA0",NADD_MUL_LINV_LEMMA0;
"NADD_MUL_LINV_LEMMA1",NADD_MUL_LINV_LEMMA1;
"NADD_MUL_LINV_LEMMA2",NADD_MUL_LINV_LEMMA2;
"NADD_MUL_LINV_LEMMA3",NADD_MUL_LINV_LEMMA3;
"NADD_MUL_LINV_LEMMA4",NADD_MUL_LINV_LEMMA4;
"NADD_MUL_LINV_LEMMA5",NADD_MUL_LINV_LEMMA5;
"NADD_MUL_LINV_LEMMA6",NADD_MUL_LINV_LEMMA6;
"NADD_MUL_LINV_LEMMA7",NADD_MUL_LINV_LEMMA7;
"NADD_MUL_LINV_LEMMA7a",NADD_MUL_LINV_LEMMA7a;
"NADD_MUL_LINV_LEMMA8",NADD_MUL_LINV_LEMMA8;
"NADD_MUL_SYM",NADD_MUL_SYM;
"NADD_MUL_WELLDEF",NADD_MUL_WELLDEF;
"NADD_MUL_WELLDEF_LEMMA",NADD_MUL_WELLDEF_LEMMA;
"NADD_NONZERO",NADD_NONZERO;
"NADD_OF_NUM",NADD_OF_NUM;
"NADD_OF_NUM_ADD",NADD_OF_NUM_ADD;
"NADD_OF_NUM_EQ",NADD_OF_NUM_EQ;
"NADD_OF_NUM_LE",NADD_OF_NUM_LE;
"NADD_OF_NUM_MUL",NADD_OF_NUM_MUL;
"NADD_OF_NUM_WELLDEF",NADD_OF_NUM_WELLDEF;
"NADD_RDISTRIB",NADD_RDISTRIB;
"NADD_SUC",NADD_SUC;
"NADD_UBOUND",NADD_UBOUND;
"NEUTRAL_ADD",NEUTRAL_ADD;
"NEUTRAL_INT_ADD",NEUTRAL_INT_ADD;
"NEUTRAL_INT_MUL",NEUTRAL_INT_MUL;
"NEUTRAL_MUL",NEUTRAL_MUL;
"NEUTRAL_REAL_ADD",NEUTRAL_REAL_ADD;
"NEUTRAL_REAL_MUL",NEUTRAL_REAL_MUL;
"NOT_ALL",NOT_ALL;
"NOT_CLAUSES",NOT_CLAUSES;
"NOT_CLAUSES_WEAK",NOT_CLAUSES_WEAK;
"NOT_CONS_NIL",NOT_CONS_NIL;
"NOT_DEF",NOT_DEF;
"NOT_EMPTY_INSERT",NOT_EMPTY_INSERT;
"NOT_EQUAL_SETS",NOT_EQUAL_SETS;
"NOT_EVEN",NOT_EVEN;
"NOT_EX",NOT_EX;
"NOT_EXISTS_THM",NOT_EXISTS_THM;
"NOT_FORALL_THM",NOT_FORALL_THM;
"NOT_IMP",NOT_IMP;
"NOT_INSERT_EMPTY",NOT_INSERT_EMPTY;
"NOT_INT_REM_2",NOT_INT_REM_2;
"NOT_IN_EMPTY",NOT_IN_EMPTY;
"NOT_LE",NOT_LE;
"NOT_LT",NOT_LT;
"NOT_ODD",NOT_ODD;
"NOT_PSUBSET_EMPTY",NOT_PSUBSET_EMPTY;
"NOT_SUC",NOT_SUC;
"NOT_UNIV_PSUBSET",NOT_UNIV_PSUBSET;
"NPRODUCT_CLAUSES",NPRODUCT_CLAUSES;
"NSUM_0",NSUM_0;
"NSUM_ADD",NSUM_ADD;
"NSUM_ADD_GEN",NSUM_ADD_GEN;
"NSUM_ADD_NUMSEG",NSUM_ADD_NUMSEG;
"NSUM_ADD_SPLIT",NSUM_ADD_SPLIT;
"NSUM_BIJECTION",NSUM_BIJECTION;
"NSUM_BOUND",NSUM_BOUND;
"NSUM_BOUND_GEN",NSUM_BOUND_GEN;
"NSUM_BOUND_LT",NSUM_BOUND_LT;
"NSUM_BOUND_LT_ALL",NSUM_BOUND_LT_ALL;
"NSUM_BOUND_LT_GEN",NSUM_BOUND_LT_GEN;
"NSUM_CASES",NSUM_CASES;
"NSUM_CLAUSES",NSUM_CLAUSES;
"NSUM_CLAUSES_LEFT",NSUM_CLAUSES_LEFT;
"NSUM_CLAUSES_NUMSEG",NSUM_CLAUSES_NUMSEG;
"NSUM_CLAUSES_NUMSEG_LE",NSUM_CLAUSES_NUMSEG_LE;
"NSUM_CLAUSES_NUMSEG_LT",NSUM_CLAUSES_NUMSEG_LT;
"NSUM_CLAUSES_RIGHT",NSUM_CLAUSES_RIGHT;
"NSUM_CLOSED",NSUM_CLOSED;
"NSUM_CLOSED_NONEMPTY",NSUM_CLOSED_NONEMPTY;
"NSUM_CONST",NSUM_CONST;
"NSUM_CONST_NUMSEG",NSUM_CONST_NUMSEG;
"NSUM_DEGENERATE",NSUM_DEGENERATE;
"NSUM_DELETE",NSUM_DELETE;
"NSUM_DELTA",NSUM_DELTA;
"NSUM_DIFF",NSUM_DIFF;
"NSUM_EQ",NSUM_EQ;
"NSUM_EQ_0",NSUM_EQ_0;
"NSUM_EQ_0_IFF",NSUM_EQ_0_IFF;
"NSUM_EQ_0_IFF_NUMSEG",NSUM_EQ_0_IFF_NUMSEG;
"NSUM_EQ_0_NUMSEG",NSUM_EQ_0_NUMSEG;
"NSUM_EQ_GENERAL",NSUM_EQ_GENERAL;
"NSUM_EQ_GENERAL_INVERSES",NSUM_EQ_GENERAL_INVERSES;
"NSUM_EQ_NUMSEG",NSUM_EQ_NUMSEG;
"NSUM_EQ_SUPERSET",NSUM_EQ_SUPERSET;
"NSUM_GROUP",NSUM_GROUP;
"NSUM_GROUP_RELATION",NSUM_GROUP_RELATION;
"NSUM_IMAGE",NSUM_IMAGE;
"NSUM_IMAGE_GEN",NSUM_IMAGE_GEN;
"NSUM_IMAGE_NONZERO",NSUM_IMAGE_NONZERO;
"NSUM_INCL_EXCL",NSUM_INCL_EXCL;
"NSUM_INJECTION",NSUM_INJECTION;
"NSUM_LE",NSUM_LE;
"NSUM_LE_GEN",NSUM_LE_GEN;
"NSUM_LE_NUMSEG",NSUM_LE_NUMSEG;
"NSUM_LMUL",NSUM_LMUL;
"NSUM_LT",NSUM_LT;
"NSUM_LT_ALL",NSUM_LT_ALL;
"NSUM_MULTICOUNT",NSUM_MULTICOUNT;
"NSUM_MULTICOUNT_GEN",NSUM_MULTICOUNT_GEN;
"NSUM_MUL_BOUND",NSUM_MUL_BOUND;
"NSUM_NSUM_PRODUCT",NSUM_NSUM_PRODUCT;
"NSUM_NSUM_RESTRICT",NSUM_NSUM_RESTRICT;
"NSUM_OFFSET",NSUM_OFFSET;
"NSUM_OFFSET_0",NSUM_OFFSET_0;
"NSUM_PAIR",NSUM_PAIR;
"NSUM_POS_BOUND",NSUM_POS_BOUND;
"NSUM_POS_LT",NSUM_POS_LT;
"NSUM_POS_LT_ALL",NSUM_POS_LT_ALL;
"NSUM_REFLECT",NSUM_REFLECT;
"NSUM_RELATED",NSUM_RELATED;
"NSUM_RELATED_NONEMPTY",NSUM_RELATED_NONEMPTY;
"NSUM_RESTRICT",NSUM_RESTRICT;
"NSUM_RESTRICT_SET",NSUM_RESTRICT_SET;
"NSUM_RMUL",NSUM_RMUL;
"NSUM_SING",NSUM_SING;
"NSUM_SING_NUMSEG",NSUM_SING_NUMSEG;
"NSUM_SUBSET",NSUM_SUBSET;
"NSUM_SUBSET_SIMPLE",NSUM_SUBSET_SIMPLE;
"NSUM_SUPERSET",NSUM_SUPERSET;
"NSUM_SUPPORT",NSUM_SUPPORT;
"NSUM_SWAP",NSUM_SWAP;
"NSUM_SWAP_NUMSEG",NSUM_SWAP_NUMSEG;
"NSUM_TRIV_NUMSEG",NSUM_TRIV_NUMSEG;
"NSUM_UNION",NSUM_UNION;
"NSUM_UNIONS_NONZERO",NSUM_UNIONS_NONZERO;
"NSUM_UNION_EQ",NSUM_UNION_EQ;
"NSUM_UNION_LZERO",NSUM_UNION_LZERO;
"NSUM_UNION_NONZERO",NSUM_UNION_NONZERO;
"NSUM_UNION_RZERO",NSUM_UNION_RZERO;
"NSUM_UNIV",NSUM_UNIV;
"NULL",NULL;
"NUMERAL",NUMERAL;
"NUMPAIR",NUMPAIR;
"NUMPAIR_DEST",NUMPAIR_DEST;
"NUMPAIR_INJ",NUMPAIR_INJ;
"NUMPAIR_INJ_LEMMA",NUMPAIR_INJ_LEMMA;
"NUMSEG_ADD_SPLIT",NUMSEG_ADD_SPLIT;
"NUMSEG_CLAUSES",NUMSEG_CLAUSES;
"NUMSEG_CLAUSES_LE",NUMSEG_CLAUSES_LE;
"NUMSEG_CLAUSES_LT",NUMSEG_CLAUSES_LT;
"NUMSEG_COMBINE_L",NUMSEG_COMBINE_L;
"NUMSEG_COMBINE_R",NUMSEG_COMBINE_R;
"NUMSEG_EMPTY",NUMSEG_EMPTY;
"NUMSEG_LE",NUMSEG_LE;
"NUMSEG_LREC",NUMSEG_LREC;
"NUMSEG_LT",NUMSEG_LT;
"NUMSEG_LT_DIMINDEX",NUMSEG_LT_DIMINDEX;
"NUMSEG_OFFSET_IMAGE",NUMSEG_OFFSET_IMAGE;
"NUMSEG_REC",NUMSEG_REC;
"NUMSEG_RREC",NUMSEG_RREC;
"NUMSEG_SING",NUMSEG_SING;
"NUMSUM",NUMSUM;
"NUMSUM_DEST",NUMSUM_DEST;
"NUMSUM_INJ",NUMSUM_INJ;
"NUM_CASES_BINARY",NUM_CASES_BINARY;
"NUM_GCD",NUM_GCD;
"NUM_LCM",NUM_LCM;
"NUM_OF_INT",NUM_OF_INT;
"NUM_OF_INT_ADD",NUM_OF_INT_ADD;
"NUM_OF_INT_MUL",NUM_OF_INT_MUL;
"NUM_OF_INT_OF_NUM",NUM_OF_INT_OF_NUM;
"NUM_OF_INT_POW",NUM_OF_INT_POW;
"NUM_REP_CASES",NUM_REP_CASES;
"NUM_REP_INDUCT",NUM_REP_INDUCT;
"NUM_REP_RULES",NUM_REP_RULES;
"ODD",ODD;
"ODD_ADD",ODD_ADD;
"ODD_DOUBLE",ODD_DOUBLE;
"ODD_EXISTS",ODD_EXISTS;
"ODD_EXP",ODD_EXP;
"ODD_MOD",ODD_MOD;
"ODD_MOD_EVEN",ODD_MOD_EVEN;
"ODD_MULT",ODD_MULT;
"ODD_SUB",ODD_SUB;
"ONE",ONE;
"ONE_ONE",ONE_ONE;
"ONE_OR_PRIME",ONE_OR_PRIME;
"ONE_OR_PRIME_DIVIDES_OR_COPRIME",ONE_OR_PRIME_DIVIDES_OR_COPRIME;
"ONTO",ONTO;
"OR_CLAUSES",OR_CLAUSES;
"OR_DEF",OR_DEF;
"OR_EXISTS_THM",OR_EXISTS_THM;
"OUTL",OUTL;
"OUTR",OUTR;
"PAIR",PAIR;
"PAIRED_ETA_THM",PAIRED_ETA_THM;
"PAIRWISE",PAIRWISE;
"PAIRWISE_AND",PAIRWISE_AND;
"PAIRWISE_APPEND",PAIRWISE_APPEND;
"PAIRWISE_CHAIN_UNIONS",PAIRWISE_CHAIN_UNIONS;
"PAIRWISE_EMPTY",PAIRWISE_EMPTY;
"PAIRWISE_IMAGE",PAIRWISE_IMAGE;
"PAIRWISE_IMP",PAIRWISE_IMP;
"PAIRWISE_IMPLIES",PAIRWISE_IMPLIES;
"PAIRWISE_INSERT",PAIRWISE_INSERT;
"PAIRWISE_INSERT_SYMMETRIC",PAIRWISE_INSERT_SYMMETRIC;
"PAIRWISE_MAP",PAIRWISE_MAP;
"PAIRWISE_MONO",PAIRWISE_MONO;
"PAIRWISE_SING",PAIRWISE_SING;
"PAIRWISE_TRANSITIVE",PAIRWISE_TRANSITIVE;
"PAIRWISE_UNION",PAIRWISE_UNION;
"PAIR_EQ",PAIR_EQ;
"PAIR_EXISTS_THM",PAIR_EXISTS_THM;
"PAIR_SURJECTIVE",PAIR_SURJECTIVE;
"PASSOC_DEF",PASSOC_DEF;
"PASTECART_COMPONENT",PASTECART_COMPONENT;
"PASTECART_EQ",PASTECART_EQ;
"PASTECART_FST_SND",PASTECART_FST_SND;
"PASTECART_INJ",PASTECART_INJ;
"PASTECART_IN_PCROSS",PASTECART_IN_PCROSS;
"PCROSS",PCROSS;
"PCROSS_DIFF",PCROSS_DIFF;
"PCROSS_EMPTY",PCROSS_EMPTY;
"PCROSS_EQ",PCROSS_EQ;
"PCROSS_EQ_EMPTY",PCROSS_EQ_EMPTY;
"PCROSS_INTER",PCROSS_INTER;
"PCROSS_INTERS",PCROSS_INTERS;
"PCROSS_INTERS_INTERS",PCROSS_INTERS_INTERS;
"PCROSS_MONO",PCROSS_MONO;
"PCROSS_SING",PCROSS_SING;
"PCROSS_UNION",PCROSS_UNION;
"PCROSS_UNIONS",PCROSS_UNIONS;
"PCROSS_UNIONS_UNIONS",PCROSS_UNIONS_UNIONS;
"POLYNOMIAL_FUNCTION_ADD",POLYNOMIAL_FUNCTION_ADD;
"POLYNOMIAL_FUNCTION_CONST",POLYNOMIAL_FUNCTION_CONST;
"POLYNOMIAL_FUNCTION_FINITE_ROOTS",POLYNOMIAL_FUNCTION_FINITE_ROOTS;
"POLYNOMIAL_FUNCTION_I",POLYNOMIAL_FUNCTION_I;
"POLYNOMIAL_FUNCTION_ID",POLYNOMIAL_FUNCTION_ID;
"POLYNOMIAL_FUNCTION_INDUCT",POLYNOMIAL_FUNCTION_INDUCT;
"POLYNOMIAL_FUNCTION_LMUL",POLYNOMIAL_FUNCTION_LMUL;
"POLYNOMIAL_FUNCTION_MUL",POLYNOMIAL_FUNCTION_MUL;
"POLYNOMIAL_FUNCTION_NEG",POLYNOMIAL_FUNCTION_NEG;
"POLYNOMIAL_FUNCTION_POW",POLYNOMIAL_FUNCTION_POW;
"POLYNOMIAL_FUNCTION_RMUL",POLYNOMIAL_FUNCTION_RMUL;
"POLYNOMIAL_FUNCTION_SUB",POLYNOMIAL_FUNCTION_SUB;
"POLYNOMIAL_FUNCTION_SUM",POLYNOMIAL_FUNCTION_SUM;
"POLYNOMIAL_FUNCTION_o",POLYNOMIAL_FUNCTION_o;
"POWERSET_CLAUSES",POWERSET_CLAUSES;
"POW_2_SQRT",POW_2_SQRT;
"POW_2_SQRT_ABS",POW_2_SQRT_ABS;
"PRE",PRE;
"PRE_ELIM_THM",PRE_ELIM_THM;
"PRE_ELIM_THM'",PRE_ELIM_THM';
"PRIME_COPRIME_EQ_NONDIVISIBLE",PRIME_COPRIME_EQ_NONDIVISIBLE;
"PRODUCT_CLAUSES",PRODUCT_CLAUSES;
"PRODUCT_MAP_RESTRICTION",PRODUCT_MAP_RESTRICTION;
"PROPERLY_DIVIDES_LE_IMP",PROPERLY_DIVIDES_LE_IMP;
"PSUBSET",PSUBSET;
"PSUBSET_ALT",PSUBSET_ALT;
"PSUBSET_INSERT_SUBSET",PSUBSET_INSERT_SUBSET;
"PSUBSET_IRREFL",PSUBSET_IRREFL;
"PSUBSET_SUBSET_TRANS",PSUBSET_SUBSET_TRANS;
"PSUBSET_TRANS",PSUBSET_TRANS;
"PSUBSET_UNIONS_PAIRWISE_DISJOINT",PSUBSET_UNIONS_PAIRWISE_DISJOINT;
"PSUBSET_UNIV",PSUBSET_UNIV;
"RAT_LEMMA1",RAT_LEMMA1;
"RAT_LEMMA2",RAT_LEMMA2;
"RAT_LEMMA3",RAT_LEMMA3;
"RAT_LEMMA4",RAT_LEMMA4;
"RAT_LEMMA5",RAT_LEMMA5;
"RDIV_LT_EQ",RDIV_LT_EQ;
"REAL_ABS_0",REAL_ABS_0;
"REAL_ABS_1",REAL_ABS_1;
"REAL_ABS_ABS",REAL_ABS_ABS;
"REAL_ABS_BETWEEN",REAL_ABS_BETWEEN;
"REAL_ABS_BETWEEN1",REAL_ABS_BETWEEN1;
"REAL_ABS_BETWEEN2",REAL_ABS_BETWEEN2;
"REAL_ABS_BOUND",REAL_ABS_BOUND;
"REAL_ABS_BOUNDS",REAL_ABS_BOUNDS;
"REAL_ABS_CASES",REAL_ABS_CASES;
"REAL_ABS_CIRCLE",REAL_ABS_CIRCLE;
"REAL_ABS_DIV",REAL_ABS_DIV;
"REAL_ABS_INF_LE",REAL_ABS_INF_LE;
"REAL_ABS_INV",REAL_ABS_INV;
"REAL_ABS_LE",REAL_ABS_LE;
"REAL_ABS_LE_SQRT",REAL_ABS_LE_SQRT;
"REAL_ABS_LE_SQRT_POS",REAL_ABS_LE_SQRT_POS;
"REAL_ABS_MUL",REAL_ABS_MUL;
"REAL_ABS_NEG",REAL_ABS_NEG;
"REAL_ABS_NUM",REAL_ABS_NUM;
"REAL_ABS_NZ",REAL_ABS_NZ;
"REAL_ABS_POS",REAL_ABS_POS;
"REAL_ABS_POW",REAL_ABS_POW;
"REAL_ABS_REFL",REAL_ABS_REFL;
"REAL_ABS_SGN",REAL_ABS_SGN;
"REAL_ABS_SIGN",REAL_ABS_SIGN;
"REAL_ABS_SIGN2",REAL_ABS_SIGN2;
"REAL_ABS_SQRT",REAL_ABS_SQRT;
"REAL_ABS_STILLNZ",REAL_ABS_STILLNZ;
"REAL_ABS_SUB",REAL_ABS_SUB;
"REAL_ABS_SUB_ABS",REAL_ABS_SUB_ABS;
"REAL_ABS_SUP_LE",REAL_ABS_SUP_LE;
"REAL_ABS_TRIANGLE",REAL_ABS_TRIANGLE;
"REAL_ABS_TRIANGLE_LE",REAL_ABS_TRIANGLE_LE;
"REAL_ABS_TRIANGLE_LT",REAL_ABS_TRIANGLE_LT;
"REAL_ABS_ZERO",REAL_ABS_ZERO;
"REAL_ABS_ZPOW",REAL_ABS_ZPOW;
"REAL_ADD2_SUB2",REAL_ADD2_SUB2;
"REAL_ADD_AC",REAL_ADD_AC;
"REAL_ADD_ASSOC",REAL_ADD_ASSOC;
"REAL_ADD_LDISTRIB",REAL_ADD_LDISTRIB;
"REAL_ADD_LID",REAL_ADD_LID;
"REAL_ADD_LINV",REAL_ADD_LINV;
"REAL_ADD_RDISTRIB",REAL_ADD_RDISTRIB;
"REAL_ADD_RID",REAL_ADD_RID;
"REAL_ADD_RINV",REAL_ADD_RINV;
"REAL_ADD_SUB",REAL_ADD_SUB;
"REAL_ADD_SUB2",REAL_ADD_SUB2;
"REAL_ADD_SYM",REAL_ADD_SYM;
"REAL_ARCH",REAL_ARCH;
"REAL_ARCH_INV",REAL_ARCH_INV;
"REAL_ARCH_LT",REAL_ARCH_LT;
"REAL_ARCH_POW",REAL_ARCH_POW;
"REAL_ARCH_POW2",REAL_ARCH_POW2;
"REAL_ARCH_POW_INV",REAL_ARCH_POW_INV;
"REAL_ARCH_SIMPLE",REAL_ARCH_SIMPLE;
"REAL_BOUNDS_LE",REAL_BOUNDS_LE;
"REAL_BOUNDS_LT",REAL_BOUNDS_LT;
"REAL_COMPLETE",REAL_COMPLETE;
"REAL_COMPLETE_SOMEPOS",REAL_COMPLETE_SOMEPOS;
"REAL_CONVEX_BOUND2_LE",REAL_CONVEX_BOUND2_LE;
"REAL_CONVEX_BOUND2_LT",REAL_CONVEX_BOUND2_LT;
"REAL_CONVEX_BOUNDS_LE",REAL_CONVEX_BOUNDS_LE;
"REAL_CONVEX_BOUNDS_LT",REAL_CONVEX_BOUNDS_LT;
"REAL_CONVEX_BOUND_GE",REAL_CONVEX_BOUND_GE;
"REAL_CONVEX_BOUND_GT",REAL_CONVEX_BOUND_GT;
"REAL_CONVEX_BOUND_LE",REAL_CONVEX_BOUND_LE;
"REAL_CONVEX_BOUND_LT",REAL_CONVEX_BOUND_LT;
"REAL_DIFFSQ",REAL_DIFFSQ;
"REAL_DIV_1",REAL_DIV_1;
"REAL_DIV_EQ_0",REAL_DIV_EQ_0;
"REAL_DIV_EQ_1",REAL_DIV_EQ_1;
"REAL_DIV_LMUL",REAL_DIV_LMUL;
"REAL_DIV_POW2",REAL_DIV_POW2;
"REAL_DIV_POW2_ALT",REAL_DIV_POW2_ALT;
"REAL_DIV_REFL",REAL_DIV_REFL;
"REAL_DIV_RMUL",REAL_DIV_RMUL;
"REAL_DIV_SQRT",REAL_DIV_SQRT;
"REAL_DOWN",REAL_DOWN;
"REAL_DOWN2",REAL_DOWN2;
"REAL_ENTIRE",REAL_ENTIRE;
"REAL_EQ_ADD_LCANCEL",REAL_EQ_ADD_LCANCEL;
"REAL_EQ_ADD_LCANCEL_0",REAL_EQ_ADD_LCANCEL_0;
"REAL_EQ_ADD_RCANCEL",REAL_EQ_ADD_RCANCEL;
"REAL_EQ_ADD_RCANCEL_0",REAL_EQ_ADD_RCANCEL_0;
"REAL_EQ_IMP_LE",REAL_EQ_IMP_LE;
"REAL_EQ_INV2",REAL_EQ_INV2;
"REAL_EQ_LCANCEL_IMP",REAL_EQ_LCANCEL_IMP;
"REAL_EQ_LDIV_EQ",REAL_EQ_LDIV_EQ;
"REAL_EQ_MUL_LCANCEL",REAL_EQ_MUL_LCANCEL;
"REAL_EQ_MUL_RCANCEL",REAL_EQ_MUL_RCANCEL;
"REAL_EQ_NEG2",REAL_EQ_NEG2;
"REAL_EQ_RCANCEL_IMP",REAL_EQ_RCANCEL_IMP;
"REAL_EQ_RDIV_EQ",REAL_EQ_RDIV_EQ;
"REAL_EQ_SGN_ABS",REAL_EQ_SGN_ABS;
"REAL_EQ_SQUARE_ABS",REAL_EQ_SQUARE_ABS;
"REAL_EQ_SUB_LADD",REAL_EQ_SUB_LADD;
"REAL_EQ_SUB_RADD",REAL_EQ_SUB_RADD;
"REAL_EVENPOW_ABS",REAL_EVENPOW_ABS;
"REAL_GROW_SHRINK",REAL_GROW_SHRINK;
"REAL_HREAL_LEMMA1",REAL_HREAL_LEMMA1;
"REAL_HREAL_LEMMA2",REAL_HREAL_LEMMA2;
"REAL_INF_ASCLOSE",REAL_INF_ASCLOSE;
"REAL_INF_BOUNDS",REAL_INF_BOUNDS;
"REAL_INF_LE",REAL_INF_LE;
"REAL_INF_LE_FINITE",REAL_INF_LE_FINITE;
"REAL_INF_LT_FINITE",REAL_INF_LT_FINITE;
"REAL_INF_UNIQUE",REAL_INF_UNIQUE;
"REAL_INV_0",REAL_INV_0;
"REAL_INV_1",REAL_INV_1;
"REAL_INV_1_LE",REAL_INV_1_LE;
"REAL_INV_1_LT",REAL_INV_1_LT;
"REAL_INV_DIV",REAL_INV_DIV;
"REAL_INV_EQ_0",REAL_INV_EQ_0;
"REAL_INV_EQ_1",REAL_INV_EQ_1;
"REAL_INV_INV",REAL_INV_INV;
"REAL_INV_LE_1",REAL_INV_LE_1;
"REAL_INV_LT_1",REAL_INV_LT_1;
"REAL_INV_MUL",REAL_INV_MUL;
"REAL_INV_NEG",REAL_INV_NEG;
"REAL_INV_POW",REAL_INV_POW;
"REAL_INV_SGN",REAL_INV_SGN;
"REAL_INV_ZPOW",REAL_INV_ZPOW;
"REAL_LET_ADD",REAL_LET_ADD;
"REAL_LET_ADD2",REAL_LET_ADD2;
"REAL_LET_ANTISYM",REAL_LET_ANTISYM;
"REAL_LET_TOTAL",REAL_LET_TOTAL;
"REAL_LET_TRANS",REAL_LET_TRANS;
"REAL_LE_01",REAL_LE_01;
"REAL_LE_ADD",REAL_LE_ADD;
"REAL_LE_ADD2",REAL_LE_ADD2;
"REAL_LE_ADDL",REAL_LE_ADDL;
"REAL_LE_ADDR",REAL_LE_ADDR;
"REAL_LE_ANTISYM",REAL_LE_ANTISYM;
"REAL_LE_DIV",REAL_LE_DIV;
"REAL_LE_DIV2_EQ",REAL_LE_DIV2_EQ;
"REAL_LE_DOUBLE",REAL_LE_DOUBLE;
"REAL_LE_INF",REAL_LE_INF;
"REAL_LE_INF_EQ",REAL_LE_INF_EQ;
"REAL_LE_INF_FINITE",REAL_LE_INF_FINITE;
"REAL_LE_INF_SUBSET",REAL_LE_INF_SUBSET;
"REAL_LE_INV",REAL_LE_INV;
"REAL_LE_INV2",REAL_LE_INV2;
"REAL_LE_INV_EQ",REAL_LE_INV_EQ;
"REAL_LE_LADD",REAL_LE_LADD;
"REAL_LE_LADD_IMP",REAL_LE_LADD_IMP;
"REAL_LE_LCANCEL_IMP",REAL_LE_LCANCEL_IMP;
"REAL_LE_LDIV_EQ",REAL_LE_LDIV_EQ;
"REAL_LE_LINV",REAL_LE_LINV;
"REAL_LE_LMUL",REAL_LE_LMUL;
"REAL_LE_LMUL_EQ",REAL_LE_LMUL_EQ;
"REAL_LE_LNEG",REAL_LE_LNEG;
"REAL_LE_LSQRT",REAL_LE_LSQRT;
"REAL_LE_LT",REAL_LE_LT;
"REAL_LE_MAX",REAL_LE_MAX;
"REAL_LE_MIN",REAL_LE_MIN;
"REAL_LE_MUL",REAL_LE_MUL;
"REAL_LE_MUL2",REAL_LE_MUL2;
"REAL_LE_MUL_EQ",REAL_LE_MUL_EQ;
"REAL_LE_NEG2",REAL_LE_NEG2;
"REAL_LE_NEGL",REAL_LE_NEGL;
"REAL_LE_NEGR",REAL_LE_NEGR;
"REAL_LE_NEGTOTAL",REAL_LE_NEGTOTAL;
"REAL_LE_POW2",REAL_LE_POW2;
"REAL_LE_POW_2",REAL_LE_POW_2;
"REAL_LE_RADD",REAL_LE_RADD;
"REAL_LE_RCANCEL_IMP",REAL_LE_RCANCEL_IMP;
"REAL_LE_RDIV_EQ",REAL_LE_RDIV_EQ;
"REAL_LE_REFL",REAL_LE_REFL;
"REAL_LE_RINV",REAL_LE_RINV;
"REAL_LE_RMUL",REAL_LE_RMUL;
"REAL_LE_RMUL_EQ",REAL_LE_RMUL_EQ;
"REAL_LE_RNEG",REAL_LE_RNEG;
"REAL_LE_RSQRT",REAL_LE_RSQRT;
"REAL_LE_SQUARE",REAL_LE_SQUARE;
"REAL_LE_SQUARE_ABS",REAL_LE_SQUARE_ABS;
"REAL_LE_SUB_LADD",REAL_LE_SUB_LADD;
"REAL_LE_SUB_RADD",REAL_LE_SUB_RADD;
"REAL_LE_SUP",REAL_LE_SUP;
"REAL_LE_SUP_FINITE",REAL_LE_SUP_FINITE;
"REAL_LE_TOTAL",REAL_LE_TOTAL;
"REAL_LE_TRANS",REAL_LE_TRANS;
"REAL_LE_TRANS_LE",REAL_LE_TRANS_LE;
"REAL_LE_TRANS_LT",REAL_LE_TRANS_LT;
"REAL_LE_TRANS_LTE",REAL_LE_TRANS_LTE;
"REAL_LNEG_UNIQ",REAL_LNEG_UNIQ;
"REAL_LSQRT_LE",REAL_LSQRT_LE;
"REAL_LTE_ADD",REAL_LTE_ADD;
"REAL_LTE_ADD2",REAL_LTE_ADD2;
"REAL_LTE_ANTISYM",REAL_LTE_ANTISYM;
"REAL_LTE_TOTAL",REAL_LTE_TOTAL;
"REAL_LTE_TRANS",REAL_LTE_TRANS;
"REAL_LT_01",REAL_LT_01;
"REAL_LT_ADD",REAL_LT_ADD;
"REAL_LT_ADD1",REAL_LT_ADD1;
"REAL_LT_ADD2",REAL_LT_ADD2;
"REAL_LT_ADDL",REAL_LT_ADDL;
"REAL_LT_ADDNEG",REAL_LT_ADDNEG;
"REAL_LT_ADDNEG2",REAL_LT_ADDNEG2;
"REAL_LT_ADDR",REAL_LT_ADDR;
"REAL_LT_ADD_SUB",REAL_LT_ADD_SUB;
"REAL_LT_ANTISYM",REAL_LT_ANTISYM;
"REAL_LT_DIV",REAL_LT_DIV;
"REAL_LT_DIV2_EQ",REAL_LT_DIV2_EQ;
"REAL_LT_GT",REAL_LT_GT;
"REAL_LT_IMP_LE",REAL_LT_IMP_LE;
"REAL_LT_IMP_NE",REAL_LT_IMP_NE;
"REAL_LT_IMP_NZ",REAL_LT_IMP_NZ;
"REAL_LT_INF_FINITE",REAL_LT_INF_FINITE;
"REAL_LT_INV",REAL_LT_INV;
"REAL_LT_INV2",REAL_LT_INV2;
"REAL_LT_INV_EQ",REAL_LT_INV_EQ;
"REAL_LT_LADD",REAL_LT_LADD;
"REAL_LT_LADD_IMP",REAL_LT_LADD_IMP;
"REAL_LT_LCANCEL_IMP",REAL_LT_LCANCEL_IMP;
"REAL_LT_LDIV_EQ",REAL_LT_LDIV_EQ;
"REAL_LT_LE",REAL_LT_LE;
"REAL_LT_LINV",REAL_LT_LINV;
"REAL_LT_LMUL",REAL_LT_LMUL;
"REAL_LT_LMUL_EQ",REAL_LT_LMUL_EQ;
"REAL_LT_LNEG",REAL_LT_LNEG;
"REAL_LT_LSQRT",REAL_LT_LSQRT;
"REAL_LT_MAX",REAL_LT_MAX;
"REAL_LT_MIN",REAL_LT_MIN;
"REAL_LT_MUL",REAL_LT_MUL;
"REAL_LT_MUL2",REAL_LT_MUL2;
"REAL_LT_MUL_EQ",REAL_LT_MUL_EQ;
"REAL_LT_NEG2",REAL_LT_NEG2;
"REAL_LT_NEGTOTAL",REAL_LT_NEGTOTAL;
"REAL_LT_NZ",REAL_LT_NZ;
"REAL_LT_POW2",REAL_LT_POW2;
"REAL_LT_POW_2",REAL_LT_POW_2;
"REAL_LT_RADD",REAL_LT_RADD;
"REAL_LT_RCANCEL_IMP",REAL_LT_RCANCEL_IMP;
"REAL_LT_RDIV_EQ",REAL_LT_RDIV_EQ;
"REAL_LT_REFL",REAL_LT_REFL;
"REAL_LT_RINV",REAL_LT_RINV;
"REAL_LT_RMUL",REAL_LT_RMUL;
"REAL_LT_RMUL_EQ",REAL_LT_RMUL_EQ;
"REAL_LT_RNEG",REAL_LT_RNEG;
"REAL_LT_RSQRT",REAL_LT_RSQRT;
"REAL_LT_SQUARE",REAL_LT_SQUARE;
"REAL_LT_SQUARE_ABS",REAL_LT_SQUARE_ABS;
"REAL_LT_SUB_LADD",REAL_LT_SUB_LADD;
"REAL_LT_SUB_RADD",REAL_LT_SUB_RADD;
"REAL_LT_SUP_FINITE",REAL_LT_SUP_FINITE;
"REAL_LT_TOTAL",REAL_LT_TOTAL;
"REAL_LT_TRANS",REAL_LT_TRANS;
"REAL_MAX_ACI",REAL_MAX_ACI;
"REAL_MAX_ASSOC",REAL_MAX_ASSOC;
"REAL_MAX_LE",REAL_MAX_LE;
"REAL_MAX_LT",REAL_MAX_LT;
"REAL_MAX_MAX",REAL_MAX_MAX;
"REAL_MAX_MIN",REAL_MAX_MIN;
"REAL_MAX_SUP",REAL_MAX_SUP;
"REAL_MAX_SYM",REAL_MAX_SYM;
"REAL_MIN_ACI",REAL_MIN_ACI;
"REAL_MIN_ASSOC",REAL_MIN_ASSOC;
"REAL_MIN_INF",REAL_MIN_INF;
"REAL_MIN_LE",REAL_MIN_LE;
"REAL_MIN_LT",REAL_MIN_LT;
"REAL_MIN_MAX",REAL_MIN_MAX;
"REAL_MIN_MIN",REAL_MIN_MIN;
"REAL_MIN_SYM",REAL_MIN_SYM;
"REAL_MUL_2",REAL_MUL_2;
"REAL_MUL_AC",REAL_MUL_AC;
"REAL_MUL_ASSOC",REAL_MUL_ASSOC;
"REAL_MUL_LID",REAL_MUL_LID;
"REAL_MUL_LINV",REAL_MUL_LINV;
"REAL_MUL_LINV_UNIQ",REAL_MUL_LINV_UNIQ;
"REAL_MUL_LNEG",REAL_MUL_LNEG;
"REAL_MUL_LZERO",REAL_MUL_LZERO;
"REAL_MUL_POS_LE",REAL_MUL_POS_LE;
"REAL_MUL_POS_LT",REAL_MUL_POS_LT;
"REAL_MUL_RID",REAL_MUL_RID;
"REAL_MUL_RINV",REAL_MUL_RINV;
"REAL_MUL_RINV_UNIQ",REAL_MUL_RINV_UNIQ;
"REAL_MUL_RNEG",REAL_MUL_RNEG;
"REAL_MUL_RZERO",REAL_MUL_RZERO;
"REAL_MUL_SYM",REAL_MUL_SYM;
"REAL_NEG_0",REAL_NEG_0;
"REAL_NEG_ADD",REAL_NEG_ADD;
"REAL_NEG_EQ",REAL_NEG_EQ;
"REAL_NEG_EQ_0",REAL_NEG_EQ_0;
"REAL_NEG_GE0",REAL_NEG_GE0;
"REAL_NEG_GT0",REAL_NEG_GT0;
"REAL_NEG_LE0",REAL_NEG_LE0;
"REAL_NEG_LMUL",REAL_NEG_LMUL;
"REAL_NEG_LT0",REAL_NEG_LT0;
"REAL_NEG_MINUS1",REAL_NEG_MINUS1;
"REAL_NEG_MUL2",REAL_NEG_MUL2;
"REAL_NEG_NEG",REAL_NEG_NEG;
"REAL_NEG_RMUL",REAL_NEG_RMUL;
"REAL_NEG_SUB",REAL_NEG_SUB;
"REAL_NOT_EQ",REAL_NOT_EQ;
"REAL_NOT_LE",REAL_NOT_LE;
"REAL_NOT_LT",REAL_NOT_LT;
"REAL_OF_INT_CLAUSES",REAL_OF_INT_CLAUSES;
"REAL_OF_NUM_ADD",REAL_OF_NUM_ADD;
"REAL_OF_NUM_CLAUSES",REAL_OF_NUM_CLAUSES;
"REAL_OF_NUM_DIV",REAL_OF_NUM_DIV;
"REAL_OF_NUM_EQ",REAL_OF_NUM_EQ;
"REAL_OF_NUM_GE",REAL_OF_NUM_GE;
"REAL_OF_NUM_GT",REAL_OF_NUM_GT;
"REAL_OF_NUM_LE",REAL_OF_NUM_LE;
"REAL_OF_NUM_LT",REAL_OF_NUM_LT;
"REAL_OF_NUM_MAX",REAL_OF_NUM_MAX;
"REAL_OF_NUM_MIN",REAL_OF_NUM_MIN;
"REAL_OF_NUM_MOD",REAL_OF_NUM_MOD;
"REAL_OF_NUM_MUL",REAL_OF_NUM_MUL;
"REAL_OF_NUM_POW",REAL_OF_NUM_POW;
"REAL_OF_NUM_SUB",REAL_OF_NUM_SUB;
"REAL_OF_NUM_SUB_CASES",REAL_OF_NUM_SUB_CASES;
"REAL_OF_NUM_SUC",REAL_OF_NUM_SUC;
"REAL_OF_NUM_SUM",REAL_OF_NUM_SUM;
"REAL_OF_NUM_SUM_GEN",REAL_OF_NUM_SUM_GEN;
"REAL_OF_NUM_SUM_NUMSEG",REAL_OF_NUM_SUM_NUMSEG;
"REAL_POLYFUN_EQ_0",REAL_POLYFUN_EQ_0;
"REAL_POLYFUN_EQ_CONST",REAL_POLYFUN_EQ_CONST;
"REAL_POLYFUN_FINITE_ROOTS",REAL_POLYFUN_FINITE_ROOTS;
"REAL_POLYFUN_ROOTBOUND",REAL_POLYFUN_ROOTBOUND;
"REAL_POLY_CLAUSES",REAL_POLY_CLAUSES;
"REAL_POLY_NEG_CLAUSES",REAL_POLY_NEG_CLAUSES;
"REAL_POS",REAL_POS;
"REAL_POS_EQ_SQUARE",REAL_POS_EQ_SQUARE;
"REAL_POS_LT",REAL_POS_LT;
"REAL_POW2_ABS",REAL_POW2_ABS;
"REAL_POW_1",REAL_POW_1;
"REAL_POW_1_LE",REAL_POW_1_LE;
"REAL_POW_1_LT",REAL_POW_1_LT;
"REAL_POW_2",REAL_POW_2;
"REAL_POW_ADD",REAL_POW_ADD;
"REAL_POW_DIV",REAL_POW_DIV;
"REAL_POW_EQ",REAL_POW_EQ;
"REAL_POW_EQ_0",REAL_POW_EQ_0;
"REAL_POW_EQ_1",REAL_POW_EQ_1;
"REAL_POW_EQ_1_IMP",REAL_POW_EQ_1_IMP;
"REAL_POW_EQ_ABS",REAL_POW_EQ_ABS;
"REAL_POW_EQ_EQ",REAL_POW_EQ_EQ;
"REAL_POW_EQ_ODD",REAL_POW_EQ_ODD;
"REAL_POW_EQ_ODD_EQ",REAL_POW_EQ_ODD_EQ;
"REAL_POW_INV",REAL_POW_INV;
"REAL_POW_LBOUND",REAL_POW_LBOUND;
"REAL_POW_LE",REAL_POW_LE;
"REAL_POW_LE2",REAL_POW_LE2;
"REAL_POW_LE2_ODD",REAL_POW_LE2_ODD;
"REAL_POW_LE2_ODD_EQ",REAL_POW_LE2_ODD_EQ;
"REAL_POW_LE2_REV",REAL_POW_LE2_REV;
"REAL_POW_LE_1",REAL_POW_LE_1;
"REAL_POW_LT",REAL_POW_LT;
"REAL_POW_LT2",REAL_POW_LT2;
"REAL_POW_LT2_ODD",REAL_POW_LT2_ODD;
"REAL_POW_LT2_ODD_EQ",REAL_POW_LT2_ODD_EQ;
"REAL_POW_LT2_REV",REAL_POW_LT2_REV;
"REAL_POW_LT_1",REAL_POW_LT_1;
"REAL_POW_MONO",REAL_POW_MONO;
"REAL_POW_MONO_INV",REAL_POW_MONO_INV;
"REAL_POW_MONO_LT",REAL_POW_MONO_LT;
"REAL_POW_MUL",REAL_POW_MUL;
"REAL_POW_NEG",REAL_POW_NEG;
"REAL_POW_NZ",REAL_POW_NZ;
"REAL_POW_ONE",REAL_POW_ONE;
"REAL_POW_POW",REAL_POW_POW;
"REAL_POW_SUB",REAL_POW_SUB;
"REAL_POW_ZERO",REAL_POW_ZERO;
"REAL_POW_ZPOW",REAL_POW_ZPOW;
"REAL_RNEG_UNIQ",REAL_RNEG_UNIQ;
"REAL_RSQRT_LE",REAL_RSQRT_LE;
"REAL_SGN",REAL_SGN;
"REAL_SGNS_EQ",REAL_SGNS_EQ;
"REAL_SGNS_EQ_ALT",REAL_SGNS_EQ_ALT;
"REAL_SGN_0",REAL_SGN_0;
"REAL_SGN_ABS",REAL_SGN_ABS;
"REAL_SGN_ABS_ALT",REAL_SGN_ABS_ALT;
"REAL_SGN_CASES",REAL_SGN_CASES;
"REAL_SGN_DIV",REAL_SGN_DIV;
"REAL_SGN_EQ",REAL_SGN_EQ;
"REAL_SGN_EQ_INEQ",REAL_SGN_EQ_INEQ;
"REAL_SGN_INEQS",REAL_SGN_INEQS;
"REAL_SGN_INV",REAL_SGN_INV;
"REAL_SGN_MUL",REAL_SGN_MUL;
"REAL_SGN_NEG",REAL_SGN_NEG;
"REAL_SGN_POW",REAL_SGN_POW;
"REAL_SGN_POW_2",REAL_SGN_POW_2;
"REAL_SGN_REAL_SGN",REAL_SGN_REAL_SGN;
"REAL_SGN_SQRT",REAL_SGN_SQRT;
"REAL_SGN_ZPOW",REAL_SGN_ZPOW;
"REAL_SHRINK_EQ",REAL_SHRINK_EQ;
"REAL_SHRINK_GALOIS",REAL_SHRINK_GALOIS;
"REAL_SHRINK_GROW",REAL_SHRINK_GROW;
"REAL_SHRINK_GROW_EQ",REAL_SHRINK_GROW_EQ;
"REAL_SHRINK_LE",REAL_SHRINK_LE;
"REAL_SHRINK_LT",REAL_SHRINK_LT;
"REAL_SHRINK_RANGE",REAL_SHRINK_RANGE;
"REAL_SOS_EQ_0",REAL_SOS_EQ_0;
"REAL_SQRT_POW_2",REAL_SQRT_POW_2;
"REAL_SUB_0",REAL_SUB_0;
"REAL_SUB_ABS",REAL_SUB_ABS;
"REAL_SUB_ADD",REAL_SUB_ADD;
"REAL_SUB_ADD2",REAL_SUB_ADD2;
"REAL_SUB_INV",REAL_SUB_INV;
"REAL_SUB_LDISTRIB",REAL_SUB_LDISTRIB;
"REAL_SUB_LE",REAL_SUB_LE;
"REAL_SUB_LNEG",REAL_SUB_LNEG;
"REAL_SUB_LT",REAL_SUB_LT;
"REAL_SUB_LZERO",REAL_SUB_LZERO;
"REAL_SUB_NEG2",REAL_SUB_NEG2;
"REAL_SUB_POLYFUN",REAL_SUB_POLYFUN;
"REAL_SUB_POLYFUN_ALT",REAL_SUB_POLYFUN_ALT;
"REAL_SUB_POW",REAL_SUB_POW;
"REAL_SUB_POW_L1",REAL_SUB_POW_L1;
"REAL_SUB_POW_R1",REAL_SUB_POW_R1;
"REAL_SUB_RDISTRIB",REAL_SUB_RDISTRIB;
"REAL_SUB_REFL",REAL_SUB_REFL;
"REAL_SUB_RNEG",REAL_SUB_RNEG;
"REAL_SUB_RZERO",REAL_SUB_RZERO;
"REAL_SUB_SUB",REAL_SUB_SUB;
"REAL_SUB_SUB2",REAL_SUB_SUB2;
"REAL_SUB_TRIANGLE",REAL_SUB_TRIANGLE;
"REAL_SUP_ASCLOSE",REAL_SUP_ASCLOSE;
"REAL_SUP_BOUNDS",REAL_SUP_BOUNDS;
"REAL_SUP_EQ_INF",REAL_SUP_EQ_INF;
"REAL_SUP_LE",REAL_SUP_LE;
"REAL_SUP_LE_EQ",REAL_SUP_LE_EQ;
"REAL_SUP_LE_FINITE",REAL_SUP_LE_FINITE;
"REAL_SUP_LE_SUBSET",REAL_SUP_LE_SUBSET;
"REAL_SUP_LT_FINITE",REAL_SUP_LT_FINITE;
"REAL_SUP_UNIQUE",REAL_SUP_UNIQUE;
"REAL_WLOG_LE",REAL_WLOG_LE;
"REAL_WLOG_LE_3",REAL_WLOG_LE_3;
"REAL_WLOG_LT",REAL_WLOG_LT;
"REAL_ZPOW_0",REAL_ZPOW_0;
"REAL_ZPOW_1",REAL_ZPOW_1;
"REAL_ZPOW_2",REAL_ZPOW_2;
"REAL_ZPOW_ADD",REAL_ZPOW_ADD;
"REAL_ZPOW_DIV",REAL_ZPOW_DIV;
"REAL_ZPOW_EQ_0",REAL_ZPOW_EQ_0;
"REAL_ZPOW_INV",REAL_ZPOW_INV;
"REAL_ZPOW_LE",REAL_ZPOW_LE;
"REAL_ZPOW_LT",REAL_ZPOW_LT;
"REAL_ZPOW_MINUS1",REAL_ZPOW_MINUS1;
"REAL_ZPOW_MUL",REAL_ZPOW_MUL;
"REAL_ZPOW_NEG",REAL_ZPOW_NEG;
"REAL_ZPOW_NUM",REAL_ZPOW_NUM;
"REAL_ZPOW_ONE",REAL_ZPOW_ONE;
"REAL_ZPOW_POW",REAL_ZPOW_POW;
"REAL_ZPOW_SUB",REAL_ZPOW_SUB;
"REAL_ZPOW_ZERO",REAL_ZPOW_ZERO;
"REAL_ZPOW_ZPOW",REAL_ZPOW_ZPOW;
"RECURSION_CASEWISE",RECURSION_CASEWISE;
"RECURSION_CASEWISE_PAIRWISE",RECURSION_CASEWISE_PAIRWISE;
"RECURSION_SUPERADMISSIBLE",RECURSION_SUPERADMISSIBLE;
"REFL_CLAUSE",REFL_CLAUSE;
"REPLICATE",REPLICATE;
"REP_ABS_PAIR",REP_ABS_PAIR;
"REST",REST;
"RESTRICTION",RESTRICTION;
"RESTRICTION_COMPOSE",RESTRICTION_COMPOSE;
"RESTRICTION_COMPOSE_LEFT",RESTRICTION_COMPOSE_LEFT;
"RESTRICTION_COMPOSE_RIGHT",RESTRICTION_COMPOSE_RIGHT;
"RESTRICTION_DEFINED",RESTRICTION_DEFINED;
"RESTRICTION_EQ",RESTRICTION_EQ;
"RESTRICTION_EXTENSION",RESTRICTION_EXTENSION;
"RESTRICTION_FIXPOINT",RESTRICTION_FIXPOINT;
"RESTRICTION_IDEMP",RESTRICTION_IDEMP;
"RESTRICTION_IN_CARTESIAN_PRODUCT",RESTRICTION_IN_CARTESIAN_PRODUCT;
"RESTRICTION_IN_EXTENSIONAL",RESTRICTION_IN_EXTENSIONAL;
"RESTRICTION_RESTRICTION",RESTRICTION_RESTRICTION;
"RESTRICTION_THM",RESTRICTION_THM;
"RESTRICTION_UNDEFINED",RESTRICTION_UNDEFINED;
"RESTRICTION_UNIQUE",RESTRICTION_UNIQUE;
"RESTRICTION_UNIQUE_ALT",RESTRICTION_UNIQUE_ALT;
"REVERSE",REVERSE;
"REVERSE_APPEND",REVERSE_APPEND;
"REVERSE_EQ_EMPTY",REVERSE_EQ_EMPTY;
"REVERSE_REVERSE",REVERSE_REVERSE;
"RIGHT_ADD_DISTRIB",RIGHT_ADD_DISTRIB;
"RIGHT_AND_EXISTS_THM",RIGHT_AND_EXISTS_THM;
"RIGHT_AND_FORALL_THM",RIGHT_AND_FORALL_THM;
"RIGHT_EXISTS_AND_THM",RIGHT_EXISTS_AND_THM;
"RIGHT_EXISTS_IMP_THM",RIGHT_EXISTS_IMP_THM;
"RIGHT_FORALL_IMP_THM",RIGHT_FORALL_IMP_THM;
"RIGHT_FORALL_OR_THM",RIGHT_FORALL_OR_THM;
"RIGHT_IMP_EXISTS_THM",RIGHT_IMP_EXISTS_THM;
"RIGHT_IMP_FORALL_THM",RIGHT_IMP_FORALL_THM;
"RIGHT_OR_DISTRIB",RIGHT_OR_DISTRIB;
"RIGHT_OR_EXISTS_THM",RIGHT_OR_EXISTS_THM;
"RIGHT_OR_FORALL_THM",RIGHT_OR_FORALL_THM;
"RIGHT_SUB_DISTRIB",RIGHT_SUB_DISTRIB;
"SELECT_AX",SELECT_AX;
"SELECT_REFL",SELECT_REFL;
"SELECT_UNIQUE",SELECT_UNIQUE;
"SETSPEC",SETSPEC;
"SET_CASES",SET_CASES;
"SET_OF_LIST_APPEND",SET_OF_LIST_APPEND;
"SET_OF_LIST_EQ_EMPTY",SET_OF_LIST_EQ_EMPTY;
"SET_OF_LIST_MAP",SET_OF_LIST_MAP;
"SET_OF_LIST_OF_SET",SET_OF_LIST_OF_SET;
"SET_PAIR_THM",SET_PAIR_THM;
"SET_PROVE_CASES",SET_PROVE_CASES;
"SET_RECURSION_LEMMA",SET_RECURSION_LEMMA;
"SIMPLE_IMAGE",SIMPLE_IMAGE;
"SIMPLE_IMAGE_GEN",SIMPLE_IMAGE_GEN;
"SING",SING;
"SING_GSPEC",SING_GSPEC;
"SING_SUBSET",SING_SUBSET;
"SKOLEM_THM",SKOLEM_THM;
"SKOLEM_THM_GEN",SKOLEM_THM_GEN;
"SND",SND;
"SNDCART_COMPONENT",SNDCART_COMPONENT;
"SNDCART_PASTECART",SNDCART_PASTECART;
"SND_DEF",SND_DEF;
"SQRT_0",SQRT_0;
"SQRT_1",SQRT_1;
"SQRT_DIV",SQRT_DIV;
"SQRT_EQ_0",SQRT_EQ_0;
"SQRT_EQ_1",SQRT_EQ_1;
"SQRT_EVEN_POW2",SQRT_EVEN_POW2;
"SQRT_INJ",SQRT_INJ;
"SQRT_INV",SQRT_INV;
"SQRT_LE_0",SQRT_LE_0;
"SQRT_LT_0",SQRT_LT_0;
"SQRT_MONO_LE",SQRT_MONO_LE;
"SQRT_MONO_LE_EQ",SQRT_MONO_LE_EQ;
"SQRT_MONO_LT",SQRT_MONO_LT;
"SQRT_MONO_LT_EQ",SQRT_MONO_LT_EQ;
"SQRT_MUL",SQRT_MUL;
"SQRT_NEG",SQRT_NEG;
"SQRT_POS_LE",SQRT_POS_LE;
"SQRT_POS_LT",SQRT_POS_LT;
"SQRT_POW2",SQRT_POW2;
"SQRT_POW_2",SQRT_POW_2;
"SQRT_UNIQUE",SQRT_UNIQUE;
"SQRT_UNIQUE_GEN",SQRT_UNIQUE_GEN;
"SQRT_WORKS",SQRT_WORKS;
"SQRT_WORKS_GEN",SQRT_WORKS_GEN;
"SUB",SUB;
"SUBSET",SUBSET;
"SUBSET_ANTISYM",SUBSET_ANTISYM;
"SUBSET_ANTISYM_EQ",SUBSET_ANTISYM_EQ;
"SUBSET_CARD_EQ",SUBSET_CARD_EQ;
"SUBSET_CARTESIAN_PRODUCT",SUBSET_CARTESIAN_PRODUCT;
"SUBSET_CROSS",SUBSET_CROSS;
"SUBSET_DELETE",SUBSET_DELETE;
"SUBSET_DIFF",SUBSET_DIFF;
"SUBSET_DISJOINT_UNION",SUBSET_DISJOINT_UNION;
"SUBSET_DISJOINT_UNION_EXISTS",SUBSET_DISJOINT_UNION_EXISTS;
"SUBSET_EMPTY",SUBSET_EMPTY;
"SUBSET_IMAGE",SUBSET_IMAGE;
"SUBSET_IMAGE_INJ",SUBSET_IMAGE_INJ;
"SUBSET_INSERT",SUBSET_INSERT;
"SUBSET_INSERT_DELETE",SUBSET_INSERT_DELETE;
"SUBSET_INTER",SUBSET_INTER;
"SUBSET_INTERS",SUBSET_INTERS;
"SUBSET_INTER_ABSORPTION",SUBSET_INTER_ABSORPTION;
"SUBSET_NUMSEG",SUBSET_NUMSEG;
"SUBSET_PCROSS",SUBSET_PCROSS;
"SUBSET_PSUBSET_TRANS",SUBSET_PSUBSET_TRANS;
"SUBSET_REFL",SUBSET_REFL;
"SUBSET_RESTRICT",SUBSET_RESTRICT;
"SUBSET_TRANS",SUBSET_TRANS;
"SUBSET_UNION",SUBSET_UNION;
"SUBSET_UNIONS",SUBSET_UNIONS;
"SUBSET_UNION_ABSORPTION",SUBSET_UNION_ABSORPTION;
"SUBSET_UNIV",SUBSET_UNIV;
"SUB_0",SUB_0;
"SUB_ADD",SUB_ADD;
"SUB_ADD_LCANCEL",SUB_ADD_LCANCEL;
"SUB_ADD_RCANCEL",SUB_ADD_RCANCEL;
"SUB_ELIM_THM",SUB_ELIM_THM;
"SUB_ELIM_THM'",SUB_ELIM_THM';
"SUB_EQ_0",SUB_EQ_0;
"SUB_PRESUC",SUB_PRESUC;
"SUB_REFL",SUB_REFL;
"SUB_SUC",SUB_SUC;
"SUC_DEF",SUC_DEF;
"SUC_INJ",SUC_INJ;
"SUC_SUB1",SUC_SUB1;
"SUM_0",SUM_0;
"SUM_ABS",SUM_ABS;
"SUM_ABS_BOUND",SUM_ABS_BOUND;
"SUM_ABS_LE",SUM_ABS_LE;
"SUM_ABS_NUMSEG",SUM_ABS_NUMSEG;
"SUM_ADD",SUM_ADD;
"SUM_ADD_GEN",SUM_ADD_GEN;
"SUM_ADD_NUMSEG",SUM_ADD_NUMSEG;
"SUM_ADD_SPLIT",SUM_ADD_SPLIT;
"SUM_BIJECTION",SUM_BIJECTION;
"SUM_BOUND",SUM_BOUND;
"SUM_BOUND_GEN",SUM_BOUND_GEN;
"SUM_BOUND_LT",SUM_BOUND_LT;
"SUM_BOUND_LT_ALL",SUM_BOUND_LT_ALL;
"SUM_BOUND_LT_GEN",SUM_BOUND_LT_GEN;
"SUM_CASES",SUM_CASES;
"SUM_CASES_1",SUM_CASES_1;
"SUM_CLAUSES",SUM_CLAUSES;
"SUM_CLAUSES_LEFT",SUM_CLAUSES_LEFT;
"SUM_CLAUSES_NUMSEG",SUM_CLAUSES_NUMSEG;
"SUM_CLAUSES_NUMSEG_LE",SUM_CLAUSES_NUMSEG_LE;
"SUM_CLAUSES_NUMSEG_LT",SUM_CLAUSES_NUMSEG_LT;
"SUM_CLAUSES_RIGHT",SUM_CLAUSES_RIGHT;
"SUM_CLOSED",SUM_CLOSED;
"SUM_CLOSED_NONEMPTY",SUM_CLOSED_NONEMPTY;
"SUM_COMBINE_L",SUM_COMBINE_L;
"SUM_COMBINE_R",SUM_COMBINE_R;
"SUM_CONST",SUM_CONST;
"SUM_CONST_NUMSEG",SUM_CONST_NUMSEG;
"SUM_DEGENERATE",SUM_DEGENERATE;
"SUM_DELETE",SUM_DELETE;
"SUM_DELETE_CASES",SUM_DELETE_CASES;
"SUM_DELTA",SUM_DELTA;
"SUM_DIFF",SUM_DIFF;
"SUM_DIFFS",SUM_DIFFS;
"SUM_DIFFS_ALT",SUM_DIFFS_ALT;
"SUM_EQ",SUM_EQ;
"SUM_EQ_0",SUM_EQ_0;
"SUM_EQ_0_NUMSEG",SUM_EQ_0_NUMSEG;
"SUM_EQ_GENERAL",SUM_EQ_GENERAL;
"SUM_EQ_GENERAL_INVERSES",SUM_EQ_GENERAL_INVERSES;
"SUM_EQ_NUMSEG",SUM_EQ_NUMSEG;
"SUM_EQ_SUPERSET",SUM_EQ_SUPERSET;
"SUM_GROUP",SUM_GROUP;
"SUM_GROUP_RELATION",SUM_GROUP_RELATION;
"SUM_IMAGE",SUM_IMAGE;
"SUM_IMAGE_GEN",SUM_IMAGE_GEN;
"SUM_IMAGE_LE",SUM_IMAGE_LE;
"SUM_IMAGE_NONZERO",SUM_IMAGE_NONZERO;
"SUM_INCL_EXCL",SUM_INCL_EXCL;
"SUM_INJECTION",SUM_INJECTION;
"SUM_LE",SUM_LE;
"SUM_LE_INCLUDED",SUM_LE_INCLUDED;
"SUM_LE_NUMSEG",SUM_LE_NUMSEG;
"SUM_LMUL",SUM_LMUL;
"SUM_LT",SUM_LT;
"SUM_LT_ALL",SUM_LT_ALL;
"SUM_MULTICOUNT",SUM_MULTICOUNT;
"SUM_MULTICOUNT_GEN",SUM_MULTICOUNT_GEN;
"SUM_MUL_BOUND",SUM_MUL_BOUND;
"SUM_NEG",SUM_NEG;
"SUM_OFFSET",SUM_OFFSET;
"SUM_OFFSET_0",SUM_OFFSET_0;
"SUM_PAIR",SUM_PAIR;
"SUM_PARTIAL_PRE",SUM_PARTIAL_PRE;
"SUM_PARTIAL_SUC",SUM_PARTIAL_SUC;
"SUM_POS_BOUND",SUM_POS_BOUND;
"SUM_POS_EQ_0",SUM_POS_EQ_0;
"SUM_POS_EQ_0_NUMSEG",SUM_POS_EQ_0_NUMSEG;
"SUM_POS_LE",SUM_POS_LE;
"SUM_POS_LE_NUMSEG",SUM_POS_LE_NUMSEG;
"SUM_POS_LT",SUM_POS_LT;
"SUM_POS_LT_ALL",SUM_POS_LT_ALL;
"SUM_REFLECT",SUM_REFLECT;
"SUM_RELATED",SUM_RELATED;
"SUM_RELATED_NONEMPTY",SUM_RELATED_NONEMPTY;
"SUM_RESTRICT",SUM_RESTRICT;
"SUM_RESTRICT_SET",SUM_RESTRICT_SET;
"SUM_RMUL",SUM_RMUL;
"SUM_SING",SUM_SING;
"SUM_SING_NUMSEG",SUM_SING_NUMSEG;
"SUM_SUB",SUM_SUB;
"SUM_SUBSET",SUM_SUBSET;
"SUM_SUBSET_SIMPLE",SUM_SUBSET_SIMPLE;
"SUM_SUB_NUMSEG",SUM_SUB_NUMSEG;
"SUM_SUM_PRODUCT",SUM_SUM_PRODUCT;
"SUM_SUM_RESTRICT",SUM_SUM_RESTRICT;
"SUM_SUPERSET",SUM_SUPERSET;
"SUM_SUPPORT",SUM_SUPPORT;
"SUM_SWAP",SUM_SWAP;
"SUM_SWAP_NUMSEG",SUM_SWAP_NUMSEG;
"SUM_TRIV_NUMSEG",SUM_TRIV_NUMSEG;
"SUM_UNION",SUM_UNION;
"SUM_UNIONS_NONZERO",SUM_UNIONS_NONZERO;
"SUM_UNION_EQ",SUM_UNION_EQ;
"SUM_UNION_LZERO",SUM_UNION_LZERO;
"SUM_UNION_NONZERO",SUM_UNION_NONZERO;
"SUM_UNION_RZERO",SUM_UNION_RZERO;
"SUM_UNIV",SUM_UNIV;
"SUM_ZERO_EXISTS",SUM_ZERO_EXISTS;
"SUP",SUP;
"SUPERADMISSIBLE_COND",SUPERADMISSIBLE_COND;
"SUPERADMISSIBLE_CONST",SUPERADMISSIBLE_CONST;
"SUPERADMISSIBLE_MATCH_GUARDED_PATTERN",SUPERADMISSIBLE_MATCH_GUARDED_PATTERN;
"SUPERADMISSIBLE_MATCH_SEQPATTERN",SUPERADMISSIBLE_MATCH_SEQPATTERN;
"SUPERADMISSIBLE_MATCH_UNGUARDED_PATTERN",SUPERADMISSIBLE_MATCH_UNGUARDED_PATTERN;
"SUPERADMISSIBLE_T",SUPERADMISSIBLE_T;
"SUPERADMISSIBLE_TAIL",SUPERADMISSIBLE_TAIL;
"SUPPORT_CLAUSES",SUPPORT_CLAUSES;
"SUPPORT_DELTA",SUPPORT_DELTA;
"SUPPORT_EMPTY",SUPPORT_EMPTY;
"SUPPORT_SUBSET",SUPPORT_SUBSET;
"SUPPORT_SUPPORT",SUPPORT_SUPPORT;
"SUP_APPROACH",SUP_APPROACH;
"SUP_EQ",SUP_EQ;
"SUP_EXISTS",SUP_EXISTS;
"SUP_FINITE",SUP_FINITE;
"SUP_FINITE_LEMMA",SUP_FINITE_LEMMA;
"SUP_INSERT_FINITE",SUP_INSERT_FINITE;
"SUP_INSERT_INSERT",SUP_INSERT_INSERT;
"SUP_SING",SUP_SING;
"SUP_UNION",SUP_UNION;
"SUP_UNIQUE",SUP_UNIQUE;
"SUP_UNIQUE_FINITE",SUP_UNIQUE_FINITE;
"SURJ",SURJ;
"SURJECTIVE_EXISTS_THM",SURJECTIVE_EXISTS_THM;
"SURJECTIVE_FORALL_THM",SURJECTIVE_FORALL_THM;
"SURJECTIVE_IFF_INJECTIVE",SURJECTIVE_IFF_INJECTIVE;
"SURJECTIVE_IFF_INJECTIVE_GEN",SURJECTIVE_IFF_INJECTIVE_GEN;
"SURJECTIVE_IMAGE",SURJECTIVE_IMAGE;
"SURJECTIVE_IMAGE_EQ",SURJECTIVE_IMAGE_EQ;
"SURJECTIVE_IMAGE_THM",SURJECTIVE_IMAGE_THM;
"SURJECTIVE_MAP",SURJECTIVE_MAP;
"SURJECTIVE_ON_IMAGE",SURJECTIVE_ON_IMAGE;
"SURJECTIVE_ON_PREIMAGE",SURJECTIVE_ON_PREIMAGE;
"SURJECTIVE_ON_RIGHT_INVERSE",SURJECTIVE_ON_RIGHT_INVERSE;
"SURJECTIVE_PREIMAGE",SURJECTIVE_PREIMAGE;
"SURJECTIVE_RIGHT_INVERSE",SURJECTIVE_RIGHT_INVERSE;
"SWAP_EXISTS_THM",SWAP_EXISTS_THM;
"SWAP_FORALL_THM",SWAP_FORALL_THM;
"TL",TL;
"TOPOLOGICAL_SORT",TOPOLOGICAL_SORT;
"TRANSITIVE_STEPWISE_LE",TRANSITIVE_STEPWISE_LE;
"TRANSITIVE_STEPWISE_LE_EQ",TRANSITIVE_STEPWISE_LE_EQ;
"TRANSITIVE_STEPWISE_LT",TRANSITIVE_STEPWISE_LT;
"TRANSITIVE_STEPWISE_LT_EQ",TRANSITIVE_STEPWISE_LT_EQ;
"TREAL_ADD_ASSOC",TREAL_ADD_ASSOC;
"TREAL_ADD_LDISTRIB",TREAL_ADD_LDISTRIB;
"TREAL_ADD_LID",TREAL_ADD_LID;
"TREAL_ADD_LINV",TREAL_ADD_LINV;
"TREAL_ADD_SYM",TREAL_ADD_SYM;
"TREAL_ADD_SYM_EQ",TREAL_ADD_SYM_EQ;
"TREAL_ADD_WELLDEF",TREAL_ADD_WELLDEF;
"TREAL_ADD_WELLDEFR",TREAL_ADD_WELLDEFR;
"TREAL_EQ_AP",TREAL_EQ_AP;
"TREAL_EQ_IMP_LE",TREAL_EQ_IMP_LE;
"TREAL_EQ_REFL",TREAL_EQ_REFL;
"TREAL_EQ_SYM",TREAL_EQ_SYM;
"TREAL_EQ_TRANS",TREAL_EQ_TRANS;
"TREAL_INV_0",TREAL_INV_0;
"TREAL_INV_WELLDEF",TREAL_INV_WELLDEF;
"TREAL_LE_ANTISYM",TREAL_LE_ANTISYM;
"TREAL_LE_LADD_IMP",TREAL_LE_LADD_IMP;
"TREAL_LE_MUL",TREAL_LE_MUL;
"TREAL_LE_REFL",TREAL_LE_REFL;
"TREAL_LE_TOTAL",TREAL_LE_TOTAL;
"TREAL_LE_TRANS",TREAL_LE_TRANS;
"TREAL_LE_WELLDEF",TREAL_LE_WELLDEF;
"TREAL_MUL_ASSOC",TREAL_MUL_ASSOC;
"TREAL_MUL_LID",TREAL_MUL_LID;
"TREAL_MUL_LINV",TREAL_MUL_LINV;
"TREAL_MUL_SYM",TREAL_MUL_SYM;
"TREAL_MUL_SYM_EQ",TREAL_MUL_SYM_EQ;
"TREAL_MUL_WELLDEF",TREAL_MUL_WELLDEF;
"TREAL_MUL_WELLDEFR",TREAL_MUL_WELLDEFR;
"TREAL_NEG_WELLDEF",TREAL_NEG_WELLDEF;
"TREAL_OF_NUM_ADD",TREAL_OF_NUM_ADD;
"TREAL_OF_NUM_EQ",TREAL_OF_NUM_EQ;
"TREAL_OF_NUM_LE",TREAL_OF_NUM_LE;
"TREAL_OF_NUM_MUL",TREAL_OF_NUM_MUL;
"TREAL_OF_NUM_WELLDEF",TREAL_OF_NUM_WELLDEF;
"TRIV_AND_EXISTS_THM",TRIV_AND_EXISTS_THM;
"TRIV_EXISTS_AND_THM",TRIV_EXISTS_AND_THM;
"TRIV_EXISTS_IMP_THM",TRIV_EXISTS_IMP_THM;
"TRIV_FORALL_IMP_THM",TRIV_FORALL_IMP_THM;
"TRIV_FORALL_OR_THM",TRIV_FORALL_OR_THM;
"TRIV_OR_FORALL_THM",TRIV_OR_FORALL_THM;
"TRUTH",TRUTH;
"TWO",TWO;
"T_DEF",T_DEF;
"UNCURRY_DEF",UNCURRY_DEF;
"UNION",UNION;
"UNIONS",UNIONS;
"UNIONS_0",UNIONS_0;
"UNIONS_1",UNIONS_1;
"UNIONS_2",UNIONS_2;
"UNIONS_DELETE_EMPTY",UNIONS_DELETE_EMPTY;
"UNIONS_DIFF",UNIONS_DIFF;
"UNIONS_GSPEC",UNIONS_GSPEC;
"UNIONS_IMAGE",UNIONS_IMAGE;
"UNIONS_INSERT",UNIONS_INSERT;
"UNIONS_INSERT_EMPTY",UNIONS_INSERT_EMPTY;
"UNIONS_INTERS",UNIONS_INTERS;
"UNIONS_IN_CHAIN",UNIONS_IN_CHAIN;
"UNIONS_MAXIMAL_SETS",UNIONS_MAXIMAL_SETS;
"UNIONS_MONO",UNIONS_MONO;
"UNIONS_MONO_IMAGE",UNIONS_MONO_IMAGE;
"UNIONS_OVER_INTERS",UNIONS_OVER_INTERS;
"UNIONS_SINGS",UNIONS_SINGS;
"UNIONS_SINGS_GEN",UNIONS_SINGS_GEN;
"UNIONS_SUBSET",UNIONS_SUBSET;
"UNIONS_UNION",UNIONS_UNION;
"UNIONS_UNIV",UNIONS_UNIV;
"UNION_ACI",UNION_ACI;
"UNION_ASSOC",UNION_ASSOC;
"UNION_COMM",UNION_COMM;
"UNION_DISJOINT_UNION",UNION_DISJOINT_UNION;
"UNION_EMPTY",UNION_EMPTY;
"UNION_IDEMPOT",UNION_IDEMPOT;
"UNION_OF",UNION_OF;
"UNION_OF_EMPTY",UNION_OF_EMPTY;
"UNION_OF_INC",UNION_OF_INC;
"UNION_OF_MONO",UNION_OF_MONO;
"UNION_OVER_INTER",UNION_OVER_INTER;
"UNION_RESTRICT",UNION_RESTRICT;
"UNION_SUBSET",UNION_SUBSET;
"UNION_UNIV",UNION_UNIV;
"UNIQUE_SKOLEM_ALT",UNIQUE_SKOLEM_ALT;
"UNIQUE_SKOLEM_THM",UNIQUE_SKOLEM_THM;
"UNIV",UNIV;
"UNIV_GSPEC",UNIV_GSPEC;
"UNIV_HAS_SIZE_DIMINDEX",UNIV_HAS_SIZE_DIMINDEX;
"UNIV_NOT_EMPTY",UNIV_NOT_EMPTY;
"UNIV_PCROSS_UNIV",UNIV_PCROSS_UNIV;
"UNIV_SUBSET",UNIV_SUBSET;
"UNWIND_THM1",UNWIND_THM1;
"UNWIND_THM2",UNWIND_THM2;
"WF",WF;
"WF_ANTISYM",WF_ANTISYM;
"WF_DCHAIN",WF_DCHAIN;
"WF_DHAIN_TRANSITIVE",WF_DHAIN_TRANSITIVE;
"WF_EQ",WF_EQ;
"WF_EREC",WF_EREC;
"WF_FALSE",WF_FALSE;
"WF_FINITE",WF_FINITE;
"WF_IND",WF_IND;
"WF_INT_MEASURE",WF_INT_MEASURE;
"WF_INT_MEASURE_2",WF_INT_MEASURE_2;
"WF_LEX",WF_LEX;
"WF_LEX_DEPENDENT",WF_LEX_DEPENDENT;
"WF_MEASURE",WF_MEASURE;
"WF_MEASURE_GEN",WF_MEASURE_GEN;
"WF_POINTWISE",WF_POINTWISE;
"WF_PSUBSET",WF_PSUBSET;
"WF_REC",WF_REC;
"WF_REC_CASES",WF_REC_CASES;
"WF_REC_CASES'",WF_REC_CASES';
"WF_REC_EXISTS",WF_REC_EXISTS;
"WF_REC_INVARIANT",WF_REC_INVARIANT;
"WF_REC_TAIL",WF_REC_TAIL;
"WF_REC_TAIL_GENERAL",WF_REC_TAIL_GENERAL;
"WF_REC_TAIL_GENERAL'",WF_REC_TAIL_GENERAL';
"WF_REC_WF",WF_REC_WF;
"WF_REC_num",WF_REC_num;
"WF_REFL",WF_REFL;
"WF_RESTRICT",WF_RESTRICT;
"WF_SUBSET",WF_SUBSET;
"WF_UREC",WF_UREC;
"WF_UREC_WF",WF_UREC_WF;
"WF_num",WF_num;
"WLOG_LE",WLOG_LE;
"WLOG_LE_3",WLOG_LE_3;
"WLOG_LT",WLOG_LT;
"WLOG_RELATION",WLOG_RELATION;
"ZBOT",ZBOT;
"ZCONSTR",ZCONSTR;
"ZCONSTR_ZBOT",ZCONSTR_ZBOT;
"ZERO_DEF",ZERO_DEF;
"ZERO_ONE_OR_PRIME",ZERO_ONE_OR_PRIME;
"ZERO_ONE_OR_PRIME_DIVPROD",ZERO_ONE_OR_PRIME_DIVPROD;
"ZIP",ZIP;
"ZIP_DEF",ZIP_DEF;
"ZRECSPACE_CASES",ZRECSPACE_CASES;
"ZRECSPACE_INDUCT",ZRECSPACE_INDUCT;
"ZRECSPACE_RULES",ZRECSPACE_RULES;
"_FALSITY_",_FALSITY_;
"_FUNCTION",_FUNCTION;
"_GUARDED_PATTERN",_GUARDED_PATTERN;
"_MATCH",_MATCH;
"_SEQPATTERN",_SEQPATTERN;
"_UNGUARDED_PATTERN",_UNGUARDED_PATTERN;
"admissible",admissible;
"bool_INDUCT",bool_INDUCT;
"bool_RECURSION",bool_RECURSION;
"cart_tybij",cart_tybij;
"cartesian_product",cartesian_product;
"char_INDUCT",char_INDUCT;
"char_RECURSION",char_RECURSION;
"cong",cong;
"coprime",coprime;
"dest_int_rep",dest_int_rep;
"dimindex",dimindex;
"disjoint_union",disjoint_union;
"dist",dist;
"divides",divides;
"eq_c",eq_c;
"finite_diff_tybij",finite_diff_tybij;
"finite_image_tybij",finite_image_tybij;
"finite_index",finite_index;
"finite_prod_tybij",finite_prod_tybij;
"finite_sum_tybij",finite_sum_tybij;
"fstcart",fstcart;
"ge_c",ge_c;
"gt_c",gt_c;
"has_inf",has_inf;
"has_sup",has_sup;
"hreal_add",hreal_add;
"hreal_add_th",hreal_add_th;
"hreal_inv",hreal_inv;
"hreal_inv_th",hreal_inv_th;
"hreal_le",hreal_le;
"hreal_le_th",hreal_le_th;
"hreal_mul",hreal_mul;
"hreal_mul_th",hreal_mul_th;
"hreal_of_num",hreal_of_num;
"hreal_of_num_th",hreal_of_num_th;
"inf",inf;
"int_abs",int_abs;
"int_abs_th",int_abs_th;
"int_abstr",int_abstr;
"int_add",int_add;
"int_add_th",int_add_th;
"int_congruent",int_congruent;
"int_coprime",int_coprime;
"int_divides",int_divides;
"int_eq",int_eq;
"int_gcd",int_gcd;
"int_ge",int_ge;
"int_gt",int_gt;
"int_lcm",int_lcm;
"int_le",int_le;
"int_lt",int_lt;
"int_max",int_max;
"int_max_th",int_max_th;
"int_min",int_min;
"int_min_th",int_min_th;
"int_mod",int_mod;
"int_mul",int_mul;
"int_mul_th",int_mul_th;
"int_neg",int_neg;
"int_neg_th",int_neg_th;
"int_of_num",int_of_num;
"int_of_num_th",int_of_num_th;
"int_pow",int_pow;
"int_pow_th",int_pow_th;
"int_rep",int_rep;
"int_sgn",int_sgn;
"int_sgn_th",int_sgn_th;
"int_sub",int_sub;
"int_sub_th",int_sub_th;
"int_tybij",int_tybij;
"integer",integer;
"iproduct",iproduct;
"is_int",is_int;
"is_nadd",is_nadd;
"is_nadd_0",is_nadd_0;
"isum",isum;
"iterate",iterate;
"iterato",iterato;
"lambda",lambda;
"le_c",le_c;
"list_CASES",list_CASES;
"list_INDUCT",list_INDUCT;
"list_RECURSION",list_RECURSION;
"list_of_seq",list_of_seq;
"list_of_set",list_of_set;
"lt_c",lt_c;
"minimal",minimal;
"mk_pair_def",mk_pair_def;
"monoidal",monoidal;
"nadd_abs",nadd_abs;
"nadd_add",nadd_add;
"nadd_eq",nadd_eq;
"nadd_inv",nadd_inv;
"nadd_le",nadd_le;
"nadd_mul",nadd_mul;
"nadd_of_num",nadd_of_num;
"nadd_rep",nadd_rep;
"nadd_rinv",nadd_rinv;
"neutral",neutral;
"nproduct",nproduct;
"nsum",nsum;
"num_Axiom",num_Axiom;
"num_CASES",num_CASES;
"num_FINITE",num_FINITE;
"num_FINITE_AVOID",num_FINITE_AVOID;
"num_INDUCTION",num_INDUCTION;
"num_INDUCTION_DOWN",num_INDUCTION_DOWN;
"num_INFINITE",num_INFINITE;
"num_INFINITE_EQ",num_INFINITE_EQ;
"num_MAX",num_MAX;
"num_RECURSION",num_RECURSION;
"num_WF",num_WF;
"num_WF_DOWN",num_WF_DOWN;
"num_WOP",num_WOP;
"num_congruent",num_congruent;
"num_coprime",num_coprime;
"num_divides",num_divides;
"num_gcd",num_gcd;
"num_lcm",num_lcm;
"num_mod",num_mod;
"num_of_int",num_of_int;
"numseg",numseg;
"o_ASSOC",o_ASSOC;
"o_DEF",o_DEF;
"o_THM",o_THM;
"one",one;
"one_Axiom",one_Axiom;
"one_DEF",one_DEF;
"one_INDUCT",one_INDUCT;
"one_RECURSION",one_RECURSION;
"one_axiom",one_axiom;
"one_tydef",one_tydef;
"option_DISTINCT",option_DISTINCT;
"option_INDUCT",option_INDUCT;
"option_INJ",option_INJ;
"option_RECURSION",option_RECURSION;
"pair_INDUCT",pair_INDUCT;
"pair_RECURSION",pair_RECURSION;
"pairwise",pairwise;
"pastecart",pastecart;
"polynomial_function",polynomial_function;
"prime",prime;
"prod_tybij",prod_tybij;
"product",product;
"product_map",product_map;
"real_INFINITE",real_INFINITE;
"real_abs",real_abs;
"real_add",real_add;
"real_add_th",real_add_th;
"real_div",real_div;
"real_ge",real_ge;
"real_gt",real_gt;
"real_inv",real_inv;
"real_inv_th",real_inv_th;
"real_le",real_le;
"real_le_th",real_le_th;
"real_lt",real_lt;
"real_max",real_max;
"real_min",real_min;
"real_mod",real_mod;
"real_mul",real_mul;
"real_mul_th",real_mul_th;
"real_neg",real_neg;
"real_neg_th",real_neg_th;
"real_of_num",real_of_num;
"real_of_num_th",real_of_num_th;
"real_pow",real_pow;
"real_sgn",real_sgn;
"real_sub",real_sub;
"real_zpow",real_zpow;
"set_of_list",set_of_list;
"sndcart",sndcart;
"sqrt",sqrt;
"string_INFINITE",string_INFINITE;
"sum",sum;
"sum_INDUCT",sum_INDUCT;
"sum_RECURSION",sum_RECURSION;
"sup",sup;
"superadmissible",superadmissible;
"support",support;
"tailadmissible",tailadmissible;
"treal_add",treal_add;
"treal_eq",treal_eq;
"treal_inv",treal_inv;
"treal_le",treal_le;
"treal_mul",treal_mul;
"treal_neg",treal_neg;
"treal_of_num",treal_of_num;
"tybit0_INDUCT",tybit0_INDUCT;
"tybit0_RECURSION",tybit0_RECURSION;
"tybit1_INDUCT",tybit1_INDUCT;
"tybit1_RECURSION",tybit1_RECURSION;
"vector",vector
];;
